@@ -110,6 +110,8 @@ protected:
 
     MHW_MEMORY_OBJECT_CONTROL_PARAMS m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_END_CODEC] = { }; //!< Cacheability settings
 
+   std::shared_ptr<void> m_hucItfNew = nullptr;
+
     //!
     //! \brief    Constructor
     //!
@@ -144,6 +146,14 @@ public:
     //!
     virtual ~MhwVdboxHucInterface() {}
 
+    //!
+    //! \brief    Get new HUC interface, temporal solution before switching from
+    //!           old interface to new one
+    //!
+    //! \return   pointer to new HUC interface
+    //!
+    virtual std::shared_ptr<void> GetNewHucInterface() { return nullptr; }
+
     //!
     //! \brief    Get Huc Status Hevc S2l Failure Mask
     //!
