@@ -409,6 +409,31 @@ public:
         MOS_STREAM_HANDLE  streamState,
         GPU_CONTEXT_HANDLE gpuContextHandle);
 
+    //! \brief    Sets the object capture flags for Linux OCA dump
+    //! \details  Sets the object capture flags for Linux OCA dump
+    //!
+    //! \param    PMOS_RESOURCE osResource
+    //!           [in] osResource
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if success else failure reason
+    //!
+    static MOS_STATUS SetObjectCapture(
+        PMOS_RESOURCE osResource);
+
+    //!
+    //! \brief   Get GpuContext
+    //! \details MOS internal toolset func to get GPU context instance
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    [in] gpuContext
+    //!           MOS GPU Context handle
+    //!
+    //! \return   GpuContextSpecificNext
+    //!           GPU Context instance got by GPU context handle, nullptr if get failed
+    //!
+    static GpuContextSpecificNext *GetGpuContext(MOS_STREAM_HANDLE streamState, GPU_CONTEXT_HANDLE handle);
+
     //!
     //! \brief    Add Command
     //! \details  [Cmd Buffer Interface] Add gpu commands into cmd buffer
@@ -437,6 +462,27 @@ public:
         uint32_t   cmdSize);
 
 #if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
+    //!
+    //! \brief    Dump Indirect state in Command Buffer
+    //!
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \param    [in] cmdBuffer
+    //!           Handle of cmd buffer to add cmd. cmd buffer handle can be get by calling GetCommandBuffer.
+    //! \param    [in] gpuNode
+    //!           Gpu node.
+    //! \param    [in] filePathPrefix
+    //!           The prefix for indirect state dump file.
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS DumpIndirectState(
+        MOS_STREAM_HANDLE     streamState,
+        COMMAND_BUFFER_HANDLE cmdBuffer,
+        MOS_GPU_NODE          gpuNode,
+        const char            *filePathPrefix);
+
     //!
     //! \brief    Dump Command Buffer
     //! \details  [Cmd Buffer Interface] Dump an existing cmd buffer
@@ -705,6 +751,35 @@ public:
         CommandList         *cmdList,
         CmdBufMgrNext       *cmdBufMgr);
 
+    //!
+    //! \brief    Setup commandlist and command pool from os interface
+    //! \details  Set the commandlist and commandPool used in this stream from os interface.
+    //!
+    //! \param    [in] pMosInterface
+    //!           pointer to the mos interface
+    //! \param    [out] streamStateDst
+    //!           Handle of Os Stream State.
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS SetupCurrentCmdListAndPoolFromOsInterface(
+        PMOS_INTERFACE      pMosInterface,
+        MOS_STREAM_HANDLE   streamState);
+
+    //!
+    //! \brief    Is Device Async or not
+    //! \details  Is Device Async or not.
+    //!
+    //! \param    [in] streamStateDst
+    //!           Handle of Os Stream State.
+    //!
+    //! \return   bool
+    //!           Return true if is async, otherwise false
+    //!
+    static bool IsAsyncDevice(
+        MOS_STREAM_HANDLE streamState);
+
     //!
     //! \brief    Setup VE Attribute Buffer
     //! \details  [Cmd Buffer Interface] Setup VE Attribute Buffer into cmd buffer.
@@ -760,8 +835,8 @@ public:
     //! \details  [Resource Interface] Get Cache Policy Memory Object in GMM corresponding to the resource usage
     //!           Caller: HAL & MHW
     //!
-    //! \param    [in] streamState
-    //!           Handle of Os Stream State
+    //! \param    [in] gmmClientContext
+    //!           Handle of gmmClientContext
     //! \param    [in] mosUsage
     //!           Resource usage as index to the memory object table
     //!           If prociding unknown usage, default state will be returned 
@@ -770,9 +845,27 @@ public:
     //!           The cache policy memory object got from MOS interface
     //!     
     static MEMORY_OBJECT_CONTROL_STATE GetCachePolicyMemoryObject(
-        MOS_STREAM_HANDLE streamState,
+        GMM_CLIENT_CONTEXT *gmmClientContext,
         MOS_HW_RESOURCE_DEF mosUsage);
 
+    //!
+    //! \brief    Get Cache Policy Memory Object
+    //! \details  [Resource Interface] Get Cache Policy Memory Object in GMM corresponding to the resource usage
+    //!           Caller: MOS
+    //!
+    //! \param    [in] gmmClientContext
+    //!           Handle of gmmClientContext
+    //! \param    [in] gmmUsage
+    //!           Resource usage value defined in gmm
+    //!           If prociding unknown usage, default state will be returned
+    //!
+    //! \return   MEMORY_OBJECT_CONTROL_STATE
+    //!           The cache policy memory object got from MOS interface
+    //!
+    static MEMORY_OBJECT_CONTROL_STATE GetGmmCachePolicyMemoryObject(
+        GMM_CLIENT_CONTEXT      *gmmClientContext,
+        GMM_RESOURCE_USAGE_TYPE gmmUsage);
+
     //!
     //! \brief    Get Cache Policy L1 Config
     //! \details  [Resource Interface] Get L1 Cache Config in GMM corresponding to the resource usage
@@ -803,7 +896,7 @@ public:
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
-    static MOS_STATUS GetReservedFromResouce(MOS_RESOURCE_HANDLE resource, uint32_t &val);
+    static MOS_STATUS GetReservedFromResource(MOS_RESOURCE_HANDLE resource, uint32_t &val);
 
     //!
     //! \brief    Get Reserved info from Stream
@@ -942,7 +1035,7 @@ public:
     //!           bit definition in MOS_GFXRES_FREE_FLAGS
     //!
     //! \return   uint32_t
-    //!           OS resouce deallc flags
+    //!           OS resource deallc flags
     //!
     static uint32_t ConvertHalFreeFlagsToOsFreeFlags(
         uint32_t halFreeFlag
@@ -1827,6 +1920,28 @@ public:
     static int32_t IsGPUHung(
         MOS_STREAM_HANDLE streamState);
 
+    //!
+    //! \brief    Get SetMarker enabled flag
+    //! \details  Get SetMarker enabled flag from streamState
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   bool
+    //!           SetMarker enabled flag
+    //!
+    static bool IsSetMarkerEnabled(
+        MOS_STREAM_HANDLE streamState);
+
+    //!
+    //! \brief    Get SetMarker resource address
+    //! \details  Get SetMarker resource address from streamState
+    //! \param    [in] streamState
+    //!           Handle of Os Stream State
+    //! \return   PMOS_RESOURCE
+    //!           SetMarker resource address
+    //!
+    static PMOS_RESOURCE GetMarkerResource(
+        MOS_STREAM_HANDLE streamState);
+
 private:
     //!
     //! \brief    Init per stream parameters
@@ -1860,20 +1975,6 @@ private:
         MOS_STREAM_HANDLE streamState,
         COMMAND_BUFFER_HANDLE cmdBuffer);
 
-    //!
-    //! \brief   Get GpuContext
-    //! \details MOS internal toolset func to get GPU context instance
-    //!
-    //! \param    [in] streamState
-    //!           Handle of Os Stream State
-    //! \param    [in] gpuContext
-    //!           MOS GPU Context handle
-    //!
-    //! \return   GpuContextSpecificNext
-    //!           GPU Context instance got by GPU context handle, nullptr if get failed
-    //!
-    static GpuContextSpecificNext *GetGpuContext(MOS_STREAM_HANDLE streamState, GPU_CONTEXT_HANDLE handle);
-
 #if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
     //! \brief    Unified dump command buffer initialization
     //! \details  check if dump command buffer was enabled and create the output directory
