@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2019, Intel Corporation
+* Copyright (c) 2009-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -41,6 +41,8 @@
 #endif
 #endif
 
+#include "media_user_setting.h"
+#include "null_hardware.h"
 extern PerfUtility *g_perfutility;
 
 #define PERF_DECODE "DECODE"
@@ -75,7 +77,6 @@ extern PerfUtility *g_perfutility;
      ((sCOMP == "MOS" && sLEVEL == "DDI") && (g_perfutility->dwPerfUtilityIsEnabled & MOS_DDI)) ||        \
      ((sCOMP == "MOS" && sLEVEL == "HAL") && (g_perfutility->dwPerfUtilityIsEnabled & MOS_HAL)))
 
-#if _RELEASE_INTERNAL
 #define PERF_UTILITY_START(TAG,COMP,LEVEL)                                 \
     do                                                                     \
     {                                                                      \
@@ -124,21 +125,12 @@ static int perf_count_stop = 0;
 #define PERF_UTILITY_PRINT                         \
     do                                             \
     {                                              \
-        if (g_perfutility->dwPerfUtilityIsEnabled) \
+        if (g_perfutility->dwPerfUtilityIsEnabled && MosUtilities::MosIsProfilerDumpEnabled()) \
         {                                          \
             g_perfutility->savePerfData();         \
         }                                          \
     } while(0)
 
-#else
-#define PERF_UTILITY_START(TAG, COMP,LEVEL) do {} while(0)
-#define PERF_UTILITY_STOP(TAG, COMP,LEVEL) do {} while(0)
-#define PERF_UTILITY_START_ONCE(TAG, COMP,LEVEL) do {} while(0)
-#define PERF_UTILITY_STOP_ONCE(TAG, COMP,LEVEL) do {} while(0)
-#define PERF_UTILITY_AUTO(TAG,COMP,LEVEL) do {} while(0)
-#define PERF_UTILITY_PRINT do {} while(0)
-#endif
-
 class AutoPerfUtility
 {
 public:
@@ -168,6 +160,7 @@ private:
 #define MOS_INVALID_APPID                   0xFFFFFFFF
 
 #define MOS_GPU_CONTEXT_CREATE_DEFAULT      1
+#define MOS_GPU_CONTEXT_CREATE_CM_DEFAULT   15
 
 #define MOS_VCS_ENGINE_USED(GpuContext) (              \
     ((GpuContext) == MOS_GPU_CONTEXT_VIDEO)         || \
@@ -205,13 +198,16 @@ private:
     ((GpuContext) == MOS_GPU_CONTEXT_VEBOX))
 #endif
 
+#define MOS_GCS_ENGINE_USED(GpuContext) (             \
+    ((GpuContext) == MOS_GPU_CONTEXT_TEE))
+
 #if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
 #define MOS_COMMAND_BUFFER_OUT_FILE        "Command_buffer_output"
 #define MOS_COMMAND_BUFFER_OUT_DIR         "Command_buffer_dumps"
 #define MOS_COMMAND_BUFFER_RENDER_ENGINE   "CS"
 #define MOS_COMMAND_BUFFER_VIDEO_ENGINE    "VCS"
 #define MOS_COMMAND_BUFFER_VEBOX_ENGINE    "VECS"
-#define MOS_COMMAND_BUFFER_RTE_ENGINE      "RTE"
+#define MOS_COMMAND_BUFFER_TEE_ENGINE      "TEE"
 #define MOS_COMMAND_BUFFER_PLATFORM_LEN    4
 #endif // MOS_COMMAND_BUFFER_DUMP_SUPPORTED
 
@@ -238,8 +234,9 @@ enum MOS_COMPONENT
     COMPONENT_VPreP,
     COMPONENT_CP,
     COMPONENT_MEMDECOMP,
+    COMPONENT_MCPY,
 };
-C_ASSERT(COMPONENT_MEMDECOMP == 9); // When adding, update assert
+C_ASSERT(COMPONENT_MCPY == 10); // When adding, update assert
 
 //!
 //! \brief Structure to OS sync parameters
@@ -258,6 +255,13 @@ typedef struct _MOS_SYNC_PARAMS
     int32_t                 bDisableLockForTranscode;   //!< Disable the lock function for transcode perf.
 } MOS_SYNC_PARAMS, *PMOS_SYNC_PARAMS;
 
+typedef enum _MOS_SCALABILITY_ENABLE_MODE
+{
+    MOS_SCALABILITY_ENABLE_MODE_FALSE      = 0,
+    MOS_SCALABILITY_ENABLE_MODE_DEFAULT    = 0x0001,
+    MOS_SCALABILITY_ENABLE_MODE_USER_FORCE = 0x0010
+} MOS_SCALABILITY_ENABLE_MODE;
+
 #if (_DEBUG || _RELEASE_INTERNAL)
 //!
 //! \brief for forcing VDBOX
@@ -316,7 +320,7 @@ typedef struct _MOS_COMMAND_BUFFER_ATTRIBUTES
     int32_t                     bEnableMediaFrameTracking;
     uint32_t                    dwMediaFrameTrackingTag;
     uint32_t                    dwMediaFrameTrackingAddrOffset;
-    MOS_RESOURCE                resMediaFrameTrackingSurface;
+    PMOS_RESOURCE               resMediaFrameTrackingSurface;
     int32_t                     bUmdSSEUEnable;
     int32_t                     bFrequencyBoost;
     void*                       pAttriVe;
@@ -358,6 +362,8 @@ typedef enum _MOS_VEBOX_NODE_IND
 #define SUBMISSION_TYPE_MULTI_PIPE_FLAGS_LAST_PIPE      (1 << SUBMISSION_TYPE_MULTI_PIPE_FLAGS_SHIFT)
 typedef int32_t MOS_SUBMISSION_TYPE;
 
+#define EXTRA_PADDING_NEEDED                            4096
+
 //!
 //! \brief Structure to command buffer
 //!
@@ -368,15 +374,16 @@ typedef struct _MOS_COMMAND_BUFFER
     // Common fields
     uint32_t            *pCmdBase;                   //!< Base    address (CPU)
     uint32_t            *pCmdPtr;                    //!< Current address (CPU)
-    int32_t             iOffset;                    //!< Current offset in bytes
-    int32_t             iRemaining;                 //!< Remaining size
-    int32_t             iTokenOffsetInCmdBuf;       //!< Pointer to (Un)Secure token's next field Offset
-    int32_t             iCmdIndex;                  //!< command buffer's index
-    MOS_VDBOX_NODE_IND  iVdboxNodeIndex;            //!< Which VDBOX buffer is binded to
-    MOS_VEBOX_NODE_IND  iVeboxNodeIndex;            //!< Which VEBOX buffer is binded to
+    int32_t             iOffset;                     //!< Current offset in bytes
+    int32_t             iRemaining;                  //!< Remaining size
+    int32_t             iTokenOffsetInCmdBuf;        //!< Pointer to (Un)Secure token's next field Offset
+    int32_t             iCmdIndex;                   //!< command buffer's index
+    MOS_VDBOX_NODE_IND  iVdboxNodeIndex;             //!< Which VDBOX buffer is binded to
+    MOS_VEBOX_NODE_IND  iVeboxNodeIndex;             //!< Which VEBOX buffer is binded to
     int32_t             iSubmissionType;
-
-    MOS_COMMAND_BUFFER_ATTRIBUTES Attributes;       //!< Attributes for the command buffer to be provided to KMD at submission
+    bool                is1stLvlBB;                  //!< indicate it's a first level BB or not
+    struct _MOS_COMMAND_BUFFER   *cmdBuf1stLvl;      //!< Pointer to 1st level command buffer.
+    MOS_COMMAND_BUFFER_ATTRIBUTES Attributes;        //!< Attributes for the command buffer to be provided to KMD at submission
 } MOS_COMMAND_BUFFER;
 
 //!
@@ -395,12 +402,31 @@ typedef struct _MOS_LOCK_PARAMS
             uint32_t NoDecompress        : 1;                                    //!< No decompression for memory compressed surface
             uint32_t Uncached            : 1;                                    //!< Use uncached lock
             uint32_t ForceCached         : 1;                                    //!< Prefer normal map to global GTT map(Uncached) if both can work
-            uint32_t Reserved            : 25;                                   //!< Reserved for expansion.
+            uint32_t DumpBeforeSubmit    : 1;                                    //!< Lock only for dump before submit
+            uint32_t DumpAfterSubmit     : 1;                                    //!< Lock only for dump after submit
+            uint32_t Reserved            : 23;                                   //!< Reserved for expansion.
         };
         uint32_t    Value;
     };
 } MOS_LOCK_PARAMS, *PMOS_LOCK_PARAMS;
 
+//!
+//! \brief flags for GFX allocation destroy
+//!
+typedef struct _MOS_GFXRES_FREE_FLAGS
+{
+    union
+    {
+        struct
+        {
+            uint32_t AssumeNotInUse : 1;
+            uint32_t SynchronousDestroy : 1;
+            uint32_t Reserved : 30;
+        };
+        uint32_t Value;
+    };
+} MOS_GFXRES_FREE_FLAGS;
+
 //!
 //! \brief Structure to Resource Flags
 //!
@@ -410,6 +436,7 @@ typedef struct _MOS_GFXRES_FLAGS
     int32_t         bOverlay;
     int32_t         bFlipChain;
     int32_t         bSVM;
+    int32_t         bCacheable;
 } MOS_GFXRES_FLAGS, *PMOS_GFXRES_FLAGS;
 
 //!
@@ -428,6 +455,7 @@ typedef struct _MOS_ALLOC_GFXRES_PARAMS
     uint32_t            dwDepth;                                                //!< [in] 0: Implies 2D resource. >=1: volume resource
     uint32_t            dwArraySize;                                            //!< [in] 0,1: 1 element. >1: N elements
     MOS_TILE_TYPE       TileType;                                               //!< [in] Defines the layout of a physical page. Optimal choice depends on usage model.
+    MOS_TILE_MODE_GMM   m_tileModeByForce;                                      //!< [in] Indicates a tile Encoding (aligned w/ GMM defination) needs set by force
     MOS_FORMAT          Format;                                                 //!< [in] Pixel format
     void                *pSystemMemory;                                         //!< [in] Optional parameter. If non null, TileType must be set to linear.
     const char          *pBufName;                                              //!< [in] Optional parameter. A string indicates the buffer name and is used for debugging. nullptr is OK.
@@ -435,6 +463,9 @@ typedef struct _MOS_ALLOC_GFXRES_PARAMS
     MOS_RESOURCE_MMC_MODE   CompressionMode;                                    //!< [in] Compression mode.
     int32_t             bIsPersistent;                                          //!< [in] Optional parameter. Used to indicate that resource can not be evicted
     int32_t             bBypassMODImpl;
+    int32_t             dwMemType;                                              //!< [in] Optional paramerter. Prefer memory type
+    MOS_HW_RESOURCE_DEF ResUsageType;                                           //!< [in] the resource usage type to determine the cache policy
+    bool                hardwareProtected;                                      //!< [in] Flag as hint that Resource can be used as hw protected
 } MOS_ALLOC_GFXRES_PARAMS, *PMOS_ALLOC_GFXRES_PARAMS;
 
 //!
@@ -477,6 +508,7 @@ struct _MOS_GPUCTX_CREATOPTIONS
 {
     uint32_t CmdBufferNumScale;
     uint32_t RAMode;
+    uint32_t ProtectMode;
     uint32_t gpuNode;
     //For slice shutdown
     union
@@ -494,6 +526,7 @@ struct _MOS_GPUCTX_CREATOPTIONS
 
     _MOS_GPUCTX_CREATOPTIONS() : CmdBufferNumScale(MOS_GPU_CONTEXT_CREATE_DEFAULT),
         RAMode(0),
+        ProtectMode(0),
         gpuNode(0),
         SSEUValue(0){}
 
@@ -510,8 +543,8 @@ class GpuCmdResInfoDump
 {
 public:
 
-    static const GpuCmdResInfoDump *GetInstance();
-    GpuCmdResInfoDump();
+    static const GpuCmdResInfoDump *GetInstance(PMOS_CONTEXT mosCtx);
+    GpuCmdResInfoDump(PMOS_CONTEXT mosCtx);
 
     void Dump(PMOS_INTERFACE pOsInterface) const;
 
@@ -541,11 +574,14 @@ private:
 #endif // MOS_COMMAND_RESINFO_DUMP_SUPPORTED
 
 class OsContextNext;
-typedef void *     OS_PER_STREAM_PARAMETERS;
+typedef void *      OS_PER_STREAM_PARAMETERS;
+typedef void *      EXTRA_PARAMS;
 typedef OsContextNext OsDeviceContext;
 typedef _MOS_GPUCTX_CREATOPTIONS GpuContextCreateOption;
 struct _MOS_INTERFACE;
 class MosVeInterface;
+class CommandList;
+class CmdBufMgrNext;
 
 struct MosStreamState
 {
@@ -553,30 +589,59 @@ struct MosStreamState
     GPU_CONTEXT_HANDLE currentGpuContextHandle = MOS_GPU_CONTEXT_INVALID_HANDLE;
     MOS_COMPONENT      component;
 
-    MosVeInterface *virtualEngineInterface = nullptr;
-    MosCpInterface *osCpInterface = nullptr;
+    CommandList        *currentCmdList      = nullptr;  //<! Command list used in async mode
+    CmdBufMgrNext      *currentCmdBufMgr    = nullptr;  //<! Cmd buffer manager used in async mode
+    bool                postponedExecution  = false;    //!< Indicate if the stream is work in postponed execution mode. This flag is only used in aync mode.
 
-    bool mediaReset    = false;
-    uint32_t GpuResetCount = 0;
+    bool supportVirtualEngine = false; //!< Flag to indicate using virtual engine interface
+    MosVeInterface *virtualEngineInterface = nullptr; //!< Interface to virtual engine state
+    bool useHwSemaForResSyncInVe = false; //!< Flag to indicate if UMD need to send HW sema cmd under this OS when there is a resource sync need with Virtual Engine interface
+    bool veEnable = false;                //!< Flag to indicate virtual engine enabled (Can enable VE without using virtual engine interface)
+    bool phasedSubmission = false;        //!< Flag to indicate if secondary command buffers are submitted together or separately due to different OS
+    bool frameSplit = true;               //!< Flag to indicate if frame split is enabled (only active when phasedSubmission is true)
+    int32_t hcpDecScalabilityMode = 0;   //!< Hcp scalability mode
+    int32_t veboxScalabilityMode  = 0;    //!< Vebox scalability mode
+
+    bool ctxBasedScheduling = false;  //!< Indicate if context based scheduling is enabled in this stream
+    bool multiNodeScaling = false;    //!< Flag to indicate if multi-node scaling is enabled for virtual engine (only active when ctxBasedScheduling is true)
+
+    int32_t ctxPriority = 0;
+    bool softReset = false;  //!< trigger soft reset
+
+    MosCpInterface *osCpInterface = nullptr; //!< CP interface
+
+    bool mediaReset    = false;  //!< Flag to indicate media reset is enabled
 
     bool simIsActive = false;  //!< Flag to indicate if Simulation is enabled
-    MOS_NULL_RENDERING_FLAGS nullHwAccelerationEnable; //!< To indicate which components to enable Null HW support
+    MOS_NULL_RENDERING_FLAGS nullHwAccelerationEnable = {};     //!< To indicate which components to enable Null HW support
+
+    bool usesPatchList = false;               //!< Uses patch list instead of graphic address directly
+    bool usesGfxAddress = false;              //!< Uses graphic address directly instead of patch list
+    bool enableKmdMediaFrameTracking = false; //!< Enable KMD Media frame tracking
+    bool usesCmdBufHeaderInResize = false;    //!< Use cmd buffer header in resize
+    bool usesCmdBufHeader = false;            //!< Use cmd buffer header
+
+    // GPU Reset Statistics
+    uint32_t gpuResetCount      = 0;
+    uint32_t gpuActiveBatch     = 0;
+    uint32_t gpuPendingBatch    = 0;
 
 #if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
     // Command buffer dump
     bool  dumpCommandBuffer = false;                      //!< Flag to indicate if Dump command buffer is enabled
     bool  dumpCommandBufferToFile = false;                //!< Indicates that the command buffer should be dumped to a file
     bool  dumpCommandBufferAsMessages = false;            //!< Indicates that the command buffer should be dumped via MOS normal messages
+    char  sDirName[MOS_MAX_HLT_FILENAME_LEN] = {0};       //!< Dump Directory name - maximum 260 bytes length
 #endif // MOS_COMMAND_BUFFER_DUMP_SUPPORTED
 
 #if _DEBUG || _RELEASE_INTERNAL
-    bool  enableDbgOvrdInVirtualEngine = false;
+    bool  enableDbgOvrdInVirtualEngine = false; //!< enable debug override in virtual engine
 
-    int32_t eForceVdbox = 0;   //!< Force select Vdbox
+    int32_t eForceVdbox = 0;  //!< Force select Vdbox
     int32_t eForceVebox = 0;  //!< Force select Vebox
 #endif // _DEBUG || _RELEASE_INTERNAL
 
-    bool  ctxBasedScheduling = false;  //!< Indicate if context based scheduling is enabled in this stream
+    bool  bGucSubmission     = false;  //!< Flag to indicate if guc submission is enabled
     OS_PER_STREAM_PARAMETERS  perStreamParameters = nullptr; //!< Parameters of OS specific per stream
 };
 
@@ -593,6 +658,7 @@ typedef void *              OsSpecificRes;       //!< stand for different os spe
 typedef void *              OS_HANDLE;           //!< stand for different os handles
 typedef MOS_SURFACE         MosResourceInfo;
 typedef void *              DDI_DEVICE_CONTEXT;  //!< stand for different os specific device context
+typedef void *              MOS_INTERFACE_HANDLE;
 
 class GpuContextMgr;
 //!
@@ -612,6 +678,9 @@ typedef struct _MOS_INTERFACE
     //!< into the kernel subsystem
     HANDLE                          CurrentGpuContextRuntimeHandle;
 
+    //!< Only used in async mode for backward compatiable
+    GPU_CONTEXT_HANDLE              m_GpuContextHandleMap[MOS_GPU_CONTEXT_MAX] = {0};
+
     // OS dependent settings, flags, limits
     int32_t                         b64bit;
     int32_t                         bDeallocateOnExit;
@@ -699,6 +768,8 @@ typedef struct _MOS_INTERFACE
     int32_t                         bTriggerVPHang;                               //!< trigger GPU HANG in VP
 #endif // (_DEBUG || _RELEASE_INTERNAL)
 
+    bool                            apoMosEnabled;                                //!< apo mos or not
+
     MEMORY_OBJECT_CONTROL_STATE (* pfnCachePolicyGetMemoryObject) (
         MOS_HW_RESOURCE_DEF         Usage,
         GMM_CLIENT_CONTEXT          *pGmmClientContext);
@@ -722,6 +793,10 @@ typedef struct _MOS_INTERFACE
         PMOS_INTERFACE              pOsInterface,
         MOS_GPU_CONTEXT             GpuContext);
 
+    MOS_STATUS (* pfnDestroyGpuComputeContext) (
+        PMOS_INTERFACE              osInterface,
+        GPU_CONTEXT_HANDLE          gpuContextHandle);
+
     MOS_STATUS (* pfnSetGpuContext) (
         PMOS_INTERFACE              pOsInterface,
         MOS_GPU_CONTEXT             GpuContext);
@@ -755,6 +830,10 @@ typedef struct _MOS_INTERFACE
     MOS_GPU_CONTEXT (* pfnGetGpuContext) (
         PMOS_INTERFACE              pOsInterface);
 
+    void* (*pfnGetGpuContextbyHandle)(
+        PMOS_INTERFACE              pOsInterface,
+        const GPU_CONTEXT_HANDLE    gpuContextHandle);
+
     GMM_CLIENT_CONTEXT* (* pfnGetGmmClientContext) (
         PMOS_INTERFACE              pOsInterface);
 
@@ -851,6 +930,9 @@ typedef struct _MOS_INTERFACE
     MEDIA_SYSTEM_INFO *(* pfnGetGtSystemInfo)(
         PMOS_INTERFACE     pOsInterface);
 
+    MOS_STATUS (*pfnGetMediaEngineInfo)(
+        PMOS_INTERFACE     pOsInterface, MEDIA_ENGINE_INFO &info);
+
     void (* pfnResetOsStates) (
         PMOS_INTERFACE              pOsInterface);
 
@@ -880,6 +962,9 @@ typedef struct _MOS_INTERFACE
         PMOS_INTERFACE              pOsInterface,
         int32_t                     *pFlag);
 
+    uint32_t (* pfnGetInterfaceVersion) (
+        PMOS_INTERFACE              pOsInterface);
+
 #if MOS_MESSAGES_ENABLED
 
     #define pfnAllocateResource(pOsInterface, pParams, pOsResource) \
@@ -973,14 +1058,23 @@ typedef struct _MOS_INTERFACE
         uint32_t              copyHeight,
         uint32_t              copyInputOffset,
         uint32_t              copyOutputOffset,
+        uint32_t              bpp,
         bool                  bOutputCompressed);
 
+    MOS_STATUS(*pfnGetMosContext) (
+        PMOS_INTERFACE        pOsInterface,
+        PMOS_CONTEXT*         mosContext);
+
     MOS_STATUS (* pfnFillResource) (
         PMOS_INTERFACE              pOsInterface,
         PMOS_RESOURCE               pResource,
         uint32_t                    dwSize,
         uint8_t                     iValue);
 
+    MOS_STATUS (*pfnUpdateResourceUsageType) (
+        PMOS_RESOURCE           pOsResource,
+        MOS_HW_RESOURCE_DEF     resUsageType);
+
     MOS_STATUS (* pfnRegisterResource) (
         PMOS_INTERFACE              pOsInterface,
         PMOS_RESOURCE               pResource,
@@ -1137,7 +1231,7 @@ typedef struct _MOS_INTERFACE
 
     MOS_STATUS (*pfnGetGpuStatusBufferResource) (
         PMOS_INTERFACE              pOsInterface,
-        PMOS_RESOURCE               pOsResource);
+        PMOS_RESOURCE               &pOsResource);
 
     MOS_STATUS (* pfnVerifyPatchListSize) (
         PMOS_INTERFACE              pOsInterface,
@@ -1187,6 +1281,9 @@ typedef struct _MOS_INTERFACE
     MOS_STATUS(*pfnSkipResourceSync)(
         PMOS_RESOURCE               pOsResource);
 
+    MOS_STATUS(*pfnSetObjectCapture)(
+        PMOS_RESOURCE               pOsResource);
+
     MOS_STATUS(*pfnSkipResourceSyncDynamic)(
         PMOS_RESOURCE               pOsResource);
 
@@ -1221,6 +1318,29 @@ typedef struct _MOS_INTERFACE
     uint64_t(*pfnGetAuxTableBaseAddr)(
         PMOS_INTERFACE              pOsInterface);
 
+    //!
+    //! \brief    Get Gpu Priority
+    //! \param    [in] pOsInterface
+    //!           pointer to the current gpu context.
+    //! \param    [out] pPriority
+    //!           pointer to the priority get from gpu context.
+    //!
+    void (*pfnGetGpuPriority)(
+        PMOS_INTERFACE              pOsInterface,
+        int32_t                     *pPriority);
+
+    //!
+    //! \brief    Set Gpu Priority
+    //!
+    //! \param    [in] pOsInterface
+    //!           pointer to the current gpu context
+    //! \param    [in] priority
+    //!           pointer to the priority set to gpu context
+    //!
+    void (*pfnSetGpuPriority)(
+        PMOS_INTERFACE              pOsInterface,
+        int32_t                     priority);
+
     //!
     //! \brief  Set slice count to shared memory and KMD
     //! \param  [in] pOsInterface
@@ -1282,6 +1402,7 @@ typedef struct _MOS_INTERFACE
     bool                            phasedSubmission = false;                     //!< Flag to indicate if secondary command buffers are submitted together (Win) or separately (Linux)
     bool                            frameSplit = true;                            //!< Flag to indicate if frame split is enabled
     bool                            bSetHandleInvalid = false;
+    bool                            bGucSubmission = false;                       //!< Flag to indicate if guc submission is enabled
     MOS_CMD_BUF_ATTRI_VE            bufAttriVe[MOS_GPU_CONTEXT_MAX];
 
     MOS_STATUS (*pfnCheckVirtualEngineSupported)(
@@ -1291,13 +1412,20 @@ typedef struct _MOS_INTERFACE
     int32_t                         bSupportMediaSoloVirtualEngine;               //!< Flag to indicate if MediaSolo uses VE solution in cmdbuffer submission.
 #endif // MOS_MEDIASOLO_SUPPORTED
     bool                            VEEnable;
+    bool                            bCanEnableSecureRt;
+
+    int32_t                         bHcpDecScalabilityMode;                       //!< enable scalability decode {mode: default, user force, false}
 #if (_DEBUG || _RELEASE_INTERNAL)
     MOS_FORCE_VEBOX                 eForceVebox;                                  //!< Force select Vebox
-    int32_t                         bHcpDecScalabilityMode;                       //!< enable scalability decode
     int32_t                         bEnableDbgOvrdInVE;                           //!< It is for all scalable engines: used together with KMD VE for UMD to specify an engine directly
-    int32_t                         bVeboxScalabilityMode;                        //!< Enable scalability vebox
     int32_t                         bSoftReset;                                   //!< trigger soft reset
 #endif // (_DEBUG || _RELEASE_INTERNAL)
+    bool streamStateIniter = false;
+
+    int32_t                         bVeboxScalabilityMode;                        //!< Enable scalability vebox
+
+    bool                            bOptimizeCpuTiming;                           //!< Optimize Cpu Timing
+
     //!< os interface extension
     void                            *pOsExt;
 } MOS_INTERFACE;
@@ -1320,6 +1448,15 @@ MOS_STATUS Mos_InitInterface(
     PMOS_CONTEXT        pOsDriverContext,
     MOS_COMPONENT       component);
 
+//! \brief    Destroy the mos interface
+//! \details  MOS Interface release
+//! \param    PMOS_INTERFACE pOsInterface
+//!           [in/out] Pointer to OS Interface
+//! \return   MOS_STATUS
+//!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+//!
+MOS_STATUS Mos_DestroyInterface(PMOS_INTERFACE pOsInterface);
+
 //! \brief    Unified OS add command to command buffer
 //! \details  Offset returned is dword aligned but size requested can be byte aligned
 //! \param    PMOS_COMMAND_BUFFER pCmdBuffer
@@ -1336,6 +1473,17 @@ MOS_STATUS Mos_AddCommand(
     const void          *pCmd,
     uint32_t            dwCmdSize);
 
+//! \brief    Unified OS get uf path info
+//! \details  return a pointer to the user feature key path info
+//! \param    PMOS_CONTEXT mosContext
+//!           [in/out] Pointer to mosContext
+//! \return   MOS_USER_FEATURE_KEY_PATH_INFO*
+//!           Return a poniter to user feature path info
+//!
+MOS_USER_FEATURE_KEY_PATH_INFO *Mos_GetDeviceUfPathInfo(
+    PMOS_CONTEXT mosContext);
+
+
 #if !EMUL
 //!
 //! \brief    Get memory object based on resource usage
@@ -1432,8 +1580,9 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
 
 struct ContextRequirement
 {
-    bool IsEnc = false;
-    bool IsPak = false;
+    bool IsEnc               = false;
+    bool IsPak               = false;
+    bool IsContextSwitchBack = false;
 };
 
 #endif  // __MOS_OS_H__
