@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2018, Intel Corporation
+* Copyright (c) 2009-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -27,7 +27,6 @@
 #ifndef __MOS_UTILITIES_H__
 #define __MOS_UTILITIES_H__
 #include "mos_utilities_common.h"
-#include "mos_defs.h"
 #include "mos_util_user_feature_keys.h"
 #include "mos_resource_defs.h"
 #include "mos_util_debug.h"
@@ -43,6 +42,7 @@
 #include <string>
 #include <vector>
 #include <map>
+#include <mutex>
 
 #define MOS_MAX_PERF_FILENAME_LEN 260
 
@@ -74,8 +74,8 @@ public:
     void setupFilePath(char *perfFilePath);
     void setupFilePath();
     bool bPerfUtilityKey;
-    char sSummaryFileName[MOS_MAX_PERF_FILENAME_LEN + 1] = "";
-    char sDetailsFileName[MOS_MAX_PERF_FILENAME_LEN + 1] = "";
+    char sSummaryFileName[MOS_MAX_PERF_FILENAME_LEN + 1] = {'\0'};
+    char sDetailsFileName[MOS_MAX_PERF_FILENAME_LEN + 1] = {'\0'};
     int32_t dwPerfUtilityIsEnabled;
 
 private:
@@ -90,50 +90,47 @@ private:
 
 private:
     static std::shared_ptr<PerfUtility> instance;
+    static std::mutex perfMutex;
     std::map<std::string, std::vector<Tick>*> records;
 };
 
-#endif // __cplusplus
-
 //!
-//! \brief    Get current run time
-//! \details  Get current run time in us
-//! \return   double
+//! \brief    Get Current time
+//! \details  Get Current time in us
+//! \return   uint64_t
 //!           Returns time in us
 //!
-double MOS_GetTime();
+uint64_t MOS_GetCurTime();
+
+#endif // __cplusplus
 
-extern int32_t MosMemAllocCounter;
-extern int32_t MosMemAllocFakeCounter;
-extern int32_t MosMemAllocCounterGfx;
-extern uint8_t MosUltFlag;
-extern uint32_t g_apoMosEnabled;
 
 class MosUtilities;
 
-#define GetTime (g_apoMosEnabled ? (MosUtilities::MosGetTime()) : (MOS_GetTime()))
-
 //! Helper Macros for MEMNINJA debug messages
-#define MOS_MEMNINJA_ALLOC_MESSAGE(ptr, size, functionName, filename, line)                                                             \
-    MOS_OS_VERBOSEMESSAGE(                                                                                                              \
-        "MemNinjaSysAlloc: Time = %f, MemNinjaCounter = %d, memPtr = %p, size = %d, functionName = \"%s\", "                            \
-        "filename = \"%s\", line = %d/", GetTime, MosMemAllocCounter, ptr, size, functionName, filename, line)
+#define MOS_MEMNINJA_ALLOC_MESSAGE(ptr, size, functionName, filename, line)                                                                                 \
+    MOS_OS_MEMNINJAMESSAGE(                                                                                                                                 \
+        "MemNinjaSysAlloc: Time = %f, MemNinjaCounter = %d, memPtr = %p, size = %d, functionName = \"%s\", "                                                \
+        "filename = \"%s\", line = %d/", MosUtilities::MosGetTime(), MosUtilities::m_mosMemAllocCounter, ptr, size, functionName, filename, line);          \
 
-#define MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line)                                                                    \
-    MOS_OS_VERBOSEMESSAGE(                                                                                                              \
-       "MemNinjaSysFree: Time = %f, MemNinjaCounter = %d, memPtr = %p, functionName = \"%s\", "                                         \
-       "filename = \"%s\", line = %d/", GetTime, MosMemAllocCounter, ptr, functionName, filename, line)
 
-#define MOS_MEMNINJA_GFX_ALLOC_MESSAGE(ptr, bufName, component, size, arraySize, functionName, filename, line)                          \
-    MOS_OS_VERBOSEMESSAGE(                                                                                                              \
-        "MemNinjaGfxAlloc: Time = %f, MemNinjaCounterGfx = %d, memPtr = %p, bufName = %s, component = %d, size = %d, "                  \
-        "arraySize = %d, functionName = \"%s\", filename = \"%s\", line = %d/", GetTime, MosMemAllocCounterGfx, ptr,\
-        bufName, component, size, arraySize, functionName, filename, line)
+#define MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line)                                                                                        \
+    MOS_OS_MEMNINJAMESSAGE(                                                                                                                                 \
+        "MemNinjaSysFree: Time = %f, MemNinjaCounter = %d, memPtr = %p, functionName = \"%s\", "                                                            \
+        "filename = \"%s\", line = %d/", MosUtilities::MosGetTime(), MosUtilities::m_mosMemAllocCounter, ptr, functionName, filename, line);                \
+
+
+#define MOS_MEMNINJA_GFX_ALLOC_MESSAGE(ptr, bufName, component, size, arraySize, functionName, filename, line)                                              \
+    MOS_OS_MEMNINJAMESSAGE(                                                                                                                                 \
+        "MemNinjaGfxAlloc: Time = %f, MemNinjaCounterGfx = %d, memPtr = %p, bufName = %s, component = %d, size = %d, "                                      \
+        "arraySize = %d, functionName = \"%s\", filename = \"%s\", line = %d/", MosUtilities::MosGetTime(), MosUtilities::m_mosMemAllocCounterGfx, ptr,     \
+        bufName, component, size, arraySize, functionName, filename, line);                                                                                 \
+
+#define MOS_MEMNINJA_GFX_FREE_MESSAGE(ptr, functionName, filename, line)                                                                                    \
+    MOS_OS_MEMNINJAMESSAGE(                                                                                                                                 \
+        "MemNinjaGfxFree: Time = %f, MemNinjaCounterGfx = %d, memPtr = %p, functionName = \"%s\", "                                                         \
+        "filename = \"%s\", line = %d/", MosUtilities::MosGetTime(), MosUtilities::m_mosMemAllocCounterGfx, ptr, functionName, filename, line);             \
 
-#define MOS_MEMNINJA_GFX_FREE_MESSAGE(ptr, functionName, filename, line)                                                                \
-    MOS_OS_VERBOSEMESSAGE(                                                                                                              \
-        "MemNinjaGfxFree: Time = %f, MemNinjaCounterGfx = %d, memPtr = %p, functionName = \"%s\", "                                     \
-        "filename = \"%s\", line = %d/", GetTime, MosMemAllocCounterGfx, ptr, functionName, filename, line)
 
 #include "mos_utilities_next.h"
 
@@ -155,17 +152,6 @@ extern "C" int32_t MOS_AtomicDecrement(int32_t *pValue);   // forward declaratio
 //    }
 //}
 
-//Memory alloc fail simulatiion related defination
-#if (_DEBUG || _RELEASE_INTERNAL)
-
-bool MOS_SimulateAllocMemoryFail(
-    size_t      size,
-    size_t      alignment,
-    const char *functionName,
-    const char *filename,
-    int32_t     line);
-#endif  //(_DEBUG || _RELEASE_INTERNAL)
-
 #if MOS_MESSAGES_ENABLED
 template<class _Ty, class... _Types>
 _Ty* MOS_NewUtil(const char *functionName,
@@ -176,29 +162,16 @@ template<class _Ty, class... _Types>
 _Ty* MOS_NewUtil(_Types&&... _Args)
 #endif
 {
-#if (_DEBUG || _RELEASE_INTERNAL)
-        //Simulate allocate memory fail if flag turned on
-        if (MOS_SimulateAllocMemoryFail(sizeof(_Ty), NO_ALLOC_ALIGNMENT, functionName, filename, line))
-        {
-            return nullptr;
-        }
+#if MOS_MESSAGES_ENABLED
+    return MosUtilities::MosNewUtil<_Ty, _Types...>(functionName, filename, line, std::forward<_Types>(_Args)...);
+#else
+    return MosUtilities::MosNewUtil<_Ty, _Types...>(std::forward<_Types>(_Args)...);
 #endif
-        _Ty* ptr = new (std::nothrow) _Ty(std::forward<_Types>(_Args)...);
-        if (ptr != nullptr)
-        {
-            MOS_AtomicIncrement(&MosMemAllocCounter);
-            MOS_MEMNINJA_ALLOC_MESSAGE(ptr, sizeof(_Ty), functionName, filename, line);
-        }
-        else
-        {
-            MOS_OS_ASSERTMESSAGE("Fail to create class.");
-        }
-        return ptr;
 }
 
 #if MOS_MESSAGES_ENABLED
 template<class _Ty, class... _Types>
-_Ty* MOS_NewArrayUtil(const char *functionName,
+_Ty *MOS_NewArrayUtil(const char *functionName,
     const char *filename,
     int32_t line, int32_t numElements)
 #else
@@ -206,20 +179,11 @@ template<class _Ty, class... _Types>
 _Ty* MOS_NewArrayUtil(int32_t numElements)
 #endif
 {
-#if (_DEBUG || _RELEASE_INTERNAL)
-        //Simulate allocate memory fail if flag turned on
-        if (MOS_SimulateAllocMemoryFail(sizeof(_Ty) * numElements, NO_ALLOC_ALIGNMENT, functionName, filename, line))
-        {
-            return nullptr;
-        }
+#if MOS_MESSAGES_ENABLED
+    return MosUtilities::MosNewArrayUtil<_Ty>(functionName, filename, line, numElements);
+#else
+    return MosUtilities::MosNewArrayUtil<_Ty>(numElements);
 #endif
-        _Ty* ptr = new (std::nothrow) _Ty[numElements]();
-        if (ptr != nullptr)
-        {
-            MOS_AtomicIncrement(&MosMemAllocCounter);
-            MOS_MEMNINJA_ALLOC_MESSAGE(ptr, numElements*sizeof(_Ty), functionName, filename, line);
-        }
-        return ptr;
 }
 
 #if MOS_MESSAGES_ENABLED
@@ -231,47 +195,44 @@ _Ty* MOS_NewArrayUtil(int32_t numElements)
 #endif
 
 #if MOS_MESSAGES_ENABLED
-template<class _Ty> inline
-void MOS_DeleteUtil(
-    const char *functionName,
-    const char *filename,
-    int32_t     line,
-    _Ty&        ptr)
+    #define MOS_DeleteUtil(functionName, filename, line, ptr) \
+        if (ptr != nullptr) \
+            { \
+                MosUtilities::MosAtomicDecrement(&MosUtilities::m_mosMemAllocCounter); \
+                MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line); \
+                delete(ptr); \
+                ptr = nullptr; \
+            }
 #else
-template<class _Ty> inline
-void MOS_DeleteUtil(_Ty& ptr)
+    #define MOS_DeleteUtil(ptr) \
+        if (ptr != nullptr) \
+            { \
+                MosUtilities::MosAtomicDecrement(&MosUtilities::m_mosMemAllocCounter); \
+                MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line); \
+                delete(ptr); \
+                ptr = nullptr; \
+            }
 #endif
-{
-    if (ptr != nullptr)
-    {
-        MOS_AtomicDecrement(&MosMemAllocCounter);
-        MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line);
-        delete(ptr);
-        ptr = nullptr;
-    }
-}
 
 #if MOS_MESSAGES_ENABLED
-template<class _Ty> inline
-void MOS_DeleteArrayUtil(
-    const char *functionName,
-    const char *filename,
-    int32_t     line,
-    _Ty&        ptr)
+    #define MOS_DeleteArrayUtil(functionName, filename, line, ptr) \
+        if (ptr != nullptr) \
+        { \
+            MosUtilities::MosAtomicDecrement(&MosUtilities::m_mosMemAllocCounter); \
+            MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line); \
+            delete[](ptr); \
+            ptr = nullptr; \
+        }
 #else
-template <class _Ty> inline
-void MOS_DeleteArrayUtil(_Ty& ptr)
+    #define MOS_DeleteArrayUtil(ptr) \
+        if (ptr != nullptr) \
+        { \
+            MosUtilities::MosAtomicDecrement(&MosUtilities::m_mosMemAllocCounter); \
+            MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line); \
+            delete[](ptr); \
+            ptr = nullptr; \
+        }
 #endif
-{
-    if (ptr != nullptr)
-    {
-        MOS_AtomicDecrement(&MosMemAllocCounter);
-        MOS_MEMNINJA_FREE_MESSAGE(ptr, functionName, filename, line);
-
-        delete[](ptr);
-        ptr = nullptr;
-    }
-}
 
 #if MOS_MESSAGES_ENABLED
 #define MOS_DeleteArray(ptr) MOS_DeleteArrayUtil(__FUNCTION__, __FILE__, __LINE__, ptr)
@@ -287,42 +248,6 @@ void MOS_DeleteArrayUtil(_Ty& ptr)
 extern "C" {
 #endif
 
-//!
-//! \brief    Init Function for MOS utilities
-//! \details  Initial MOS utilities related structures, and only execute once for multiple entries
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_utilities_init();
-
-//!
-//! \brief    Close Function for MOS utilities
-//! \details  close/remove MOS utilities related structures, and only execute once for multiple entries
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_utilities_close();
-
-//!
-//! \brief    Init Function for MOS OS specific utilities
-//! \details  Initial MOS OS specific utilities related structures, and only execute once for multiple entries
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_OS_Utilities_Init();
-
-//!
-//! \brief    Close Function for MOS OS utilities
-//! \details  close/remove MOS OS utilities related structures, and only execute once for multiple entries
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_OS_Utilities_Close();
-
 //------------------------------------------------------------------------------
 //  Allocate, free and set a memory region
 //------------------------------------------------------------------------------
@@ -807,57 +732,13 @@ MOS_FUNC_EXPORT MOS_STATUS MOS_EXPORT_DECL DumpUserFeatureKeyDefinitionsMedia();
 //!
 //! \brief    Generate a User Feature Keys XML file according to user feature keys table in MOS
 //! \details  Generate a User Feature Keys XML files according to MOSUserFeatureDescFields
+//! \param    [in] mosCtx
+//!           os device ctx handle
 //! \return   MOS_STATUS
 //!           Returns one of the MOS_STATUS error codes if failed,
 //!           else MOS_STATUS_SUCCESS
 //!
-MOS_STATUS MOS_GenerateUserFeatureKeyXML();
-
-//!
-//! \brief    Get the User Feature Value from Table
-//! \details  Get the related User Feature Value item according to Filter rules , and pass the item
-//!            into return callback function
-//! \param    [in] descTable
-//!           The user feature key description table
-//! \param    [in] numOfItems
-//!           Number of user feature keys described in the table
-//! \param    [in] maxId
-//!           Max value ID in the table
-//! \param    [out] keyValueMap
-//!           Optional pointer to the value map where the table items will be linked to, could be nullptr
-//! \param    [in] CallbackFunc
-//!           Pointer to the Callback function, and pass the User Feature Value item as its parameter
-//! \param    [in] pUserFeatureKeyFilter
-//!           use the filter rule to select some User Feature Value item
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_GetItemFromMOSUserFeatureDescField(
-    MOS_USER_FEATURE_VALUE      *descTable,
-    uint32_t                    numOfItems,
-    uint32_t                    maxId,
-    MOS_USER_FEATURE_VALUE_MAP  *keyValueMap,
-    MOS_STATUS                  (*CallbackFunc)(MOS_USER_FEATURE_VALUE_MAP *, PMOS_USER_FEATURE_VALUE),
-    PMOS_USER_FEATURE_VALUE     pUserFeatureKeyFilter);
-
-//!
-//! \brief    Set the User Feature Default Value
-//! \details  Set the User Feature Default Value in the user feature key map
-//! \param    [in] pOsUserFeatureInterface
-//!           Pointer to OS User Interface structure
-//! \param    [in] pWriteValues
-//!           Pointer to User Feature Write Data
-//! \param    [in] uiNumOfValues
-//!           Number of User Feature Write Data
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_UserFeature_SetDefaultValues(
-    PMOS_USER_FEATURE_INTERFACE             pOsUserFeatureInterface,
-    PMOS_USER_FEATURE_VALUE_WRITE_DATA      pWriteValues,
-    uint32_t                                uiNumOfValues);
+MOS_STATUS MOS_GenerateUserFeatureKeyXML(MOS_CONTEXT_HANDLE mosCtx);
 
 //!
 //! \brief    Link user feature key description table items to specified UserFeatureKeyTable
@@ -944,29 +825,6 @@ MOS_STATUS MOS_CopyUserFeatureValueData(
     MOS_USER_FEATURE_VALUE_TYPE ValueType
 );
 
-//!
-//! \brief    Free the allocated memory for the related Value type
-//! \details  Free the allocated memory for the related Value type
-//! \param    [in] pData
-//!           Pointer to the User Feature Value Data
-//! \param    [in] ValueType
-//!           related Value Type needed to be deallocated.
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_DestroyUserFeatureData(
-    PMOS_USER_FEATURE_VALUE_DATA pData,
-    MOS_USER_FEATURE_VALUE_TYPE  ValueType);
-
-#ifdef  __MOS_USER_FEATURE_WA_
-MOS_STATUS MOS_UserFeature_ReadValue (
-    PMOS_USER_FEATURE_INTERFACE       pOsUserFeatureInterface,
-    PMOS_USER_FEATURE                 pUserFeature,
-    const char                        *pValueName,
-    MOS_USER_FEATURE_VALUE_TYPE       ValueType);
-#endif
-
 //!
 //! \brief    Read Single Value from User Feature based on value of enum type in MOS_USER_FEATURE_VALUE_TYPE
 //! \details  This is a unified funtion to read user feature key for all components.
@@ -1012,6 +870,8 @@ MOS_STATUS MOS_UserFeature_ReadValue (
 //!           value of enum type in MOS_USER_FEATURE_VALUE_TYPE. declares the user feature key to be readed
 //! \param    [in,out] pValueData
 //!           Pointer to User Feature Data
+//! \param    [in] mosCtx
+//!           Pointer to ddi device ctx
 //! \return   MOS_STATUS
 //!           Returns one of the MOS_STATUS error codes if failed,
 //!           else MOS_STATUS_SUCCESS
@@ -1024,14 +884,11 @@ MOS_STATUS MOS_UserFeature_ReadValue (
 //!                                          No default value or User Feature Key value return
 //! 
 //!
-#ifdef  __MOS_USER_FEATURE_WA_
 MOS_STATUS MOS_UserFeature_ReadValue_ID(
-#else
-MOS_STATUS MOS_UserFeature_ReadValue(
-#endif
     PMOS_USER_FEATURE_INTERFACE  pOsUserFeatureInterface,
     uint32_t                     ValueID,
-    PMOS_USER_FEATURE_VALUE_DATA pValueData);
+    PMOS_USER_FEATURE_VALUE_DATA pValueData,
+    MOS_CONTEXT_HANDLE           mosCtx);
 
 //!
 //! \brief    Write Values to User Feature with specified ID
@@ -1044,44 +901,42 @@ MOS_STATUS MOS_UserFeature_ReadValue(
 //!           Pointer to User Feature Data, and related User Feature Key ID (enum type in MOS_USER_FEATURE_VALUE_TYPE)
 //! \param    [in] uiNumOfValues
 //!           number of user feature keys to be written.
+//! \param    [in] mosCtx
+//!           Pointer to ddi device ctx
 //! \return   MOS_STATUS
 //!           Returns one of the MOS_STATUS error codes if failed,
 //!           else MOS_STATUS_SUCCESS
 //!
-#ifdef  __MOS_USER_FEATURE_WA_
 MOS_STATUS MOS_UserFeature_WriteValues_ID(
-#else
-MOS_STATUS MOS_UserFeature_WriteValues(
-#endif
     PMOS_USER_FEATURE_INTERFACE              pOsUserFeatureInterface,
     PMOS_USER_FEATURE_VALUE_WRITE_DATA       pWriteValues,
-    uint32_t                                 uiNumOfValues);
-
+    uint32_t                                 uiNumOfValues,
+    MOS_CONTEXT_HANDLE                       mosCtx);
 
 // User Feature Report Writeout
-#define WriteUserFeature64(key, value)\
-{\
-    MOS_USER_FEATURE_VALUE_WRITE_DATA   UserFeatureWriteData = __NULL_USER_FEATURE_VALUE_WRITE_DATA__;\
-    UserFeatureWriteData.Value.i64Data  = (value);\
-    UserFeatureWriteData.ValueID        = (key);\
-    MOS_UserFeature_WriteValues_ID(nullptr, &UserFeatureWriteData, 1);\
+#define WriteUserFeature64(key, value, mosCtx)                                                       \
+{                                                                                                    \
+    MOS_USER_FEATURE_VALUE_WRITE_DATA UserFeatureWriteData = __NULL_USER_FEATURE_VALUE_WRITE_DATA__; \
+    UserFeatureWriteData.Value.i64Data                     = (value);                                \
+    UserFeatureWriteData.ValueID                           = (key);                                  \
+    MOS_UserFeature_WriteValues_ID(nullptr, &UserFeatureWriteData, 1, mosCtx);                       \
 }
 
-#define WriteUserFeature(key, value)\
-{\
-    MOS_USER_FEATURE_VALUE_WRITE_DATA   UserFeatureWriteData = __NULL_USER_FEATURE_VALUE_WRITE_DATA__;\
-    UserFeatureWriteData.Value.i32Data  = (value);\
-    UserFeatureWriteData.ValueID        = (key);\
-    MOS_UserFeature_WriteValues_ID(nullptr, &UserFeatureWriteData, 1);\
+#define WriteUserFeature(key, value, mosCtx)                                                         \
+{                                                                                                    \
+    MOS_USER_FEATURE_VALUE_WRITE_DATA UserFeatureWriteData = __NULL_USER_FEATURE_VALUE_WRITE_DATA__; \
+    UserFeatureWriteData.Value.i32Data                     = (value);                                \
+    UserFeatureWriteData.ValueID                           = (key);                                  \
+    MOS_UserFeature_WriteValues_ID(nullptr, &UserFeatureWriteData, 1, mosCtx);                       \
 }
 
-#define WriteUserFeatureString(key, value, len)\
-{\
-    MOS_USER_FEATURE_VALUE_WRITE_DATA   UserFeatureWriteData = __NULL_USER_FEATURE_VALUE_WRITE_DATA__;\
-    UserFeatureWriteData.Value.StringData.pStringData = (value);\
-    UserFeatureWriteData.Value.StringData.uSize = (len);\
-    UserFeatureWriteData.ValueID        = (key);\
-    MOS_UserFeature_WriteValues_ID(nullptr, &UserFeatureWriteData, 1);\
+#define WriteUserFeatureString(key, value, len, mosCtx)                                              \
+{                                                                                                    \
+    MOS_USER_FEATURE_VALUE_WRITE_DATA UserFeatureWriteData = __NULL_USER_FEATURE_VALUE_WRITE_DATA__; \
+    UserFeatureWriteData.Value.StringData.pStringData      = (value);                                \
+    UserFeatureWriteData.Value.StringData.uSize            = (len + 1);                              \
+    UserFeatureWriteData.ValueID                           = (key);                                  \
+    MOS_UserFeature_WriteValues_ID(nullptr, &UserFeatureWriteData, 1, mosCtx);                       \
 }
 
 //!
@@ -1117,38 +972,6 @@ const char* MOS_UserFeature_LookupReadPath(
 const char* MOS_UserFeature_LookupWritePath(
     uint32_t ValueID);
 
-//!
-//! \brief    Enable user feature change notification
-//! \details  Enable user feature change notification
-//!           Create notification data and register the wait event
-//! \param    [in] pOsUserFeatureInterface
-//!           Pointer to OS User Interface structure
-//! \param    [in/out] pNotification
-//!           Pointer to User Feature Notification Data
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_UserFeature_EnableNotification(
-    PMOS_USER_FEATURE_INTERFACE               pOsUserFeatureInterface,
-    PMOS_USER_FEATURE_NOTIFY_DATA             pNotification);
-
-//!
-//! \brief    Disable user feature change notification
-//! \details  Disable user feature change notification
-//!           Unregister the wait event and frees notification data
-//! \param    [in] pOsUserFeatureInterface
-//!           Pointer to OS User Interface structure
-//! \param    [in/out] pNotification
-//!           Pointer to User Feature Notification Data
-//! \return   MOS_STATUS
-//!           Returns one of the MOS_STATUS error codes if failed,
-//!           else MOS_STATUS_SUCCESS
-//!
-MOS_STATUS MOS_UserFeature_DisableNotification(
-    PMOS_USER_FEATURE_INTERFACE                pOsUserFeatureInterface,
-    PMOS_USER_FEATURE_NOTIFY_DATA              pNotification);
-
 //!
 //! \brief    Parses the user feature path and gets type and sub path
 //! \details  Parses the user feature path and gets type and sub path
@@ -1444,7 +1267,8 @@ MOS_STATUS MOS_UserFeatureOpenKey(
     const char        *lpSubKey,
     uint32_t          ulOptions,
     uint32_t          samDesired,
-    void              **phkResult);
+    void              **phkResult,
+    MOS_USER_FEATURE_KEY_PATH_INFO *ufInfo = nullptr);
 
 //!
 //! \brief    Closes a handle to the specified user feature key
@@ -2010,6 +1834,22 @@ void MOS_TraceEventInit();
 //!
 void MOS_TraceEventClose();
 
+//!
+//! \brief    setup static platform info for trace events
+//! \details  send static platform info to trace struct, which itself determine when to send them.
+//!           static platform info should only send 1 time per trace capture, no more no less.
+//! \param    [in] driver version
+//! \param    [in] platform family
+//! \param    [in] render family
+//! \param    [in] device id
+//! \return   void
+//!
+void MOS_TraceSetupInfo(
+    uint32_t DrvVer,
+    uint32_t PlatFamily,
+    uint32_t RenderFamily,
+    uint32_t DeviceID);
+
 //!
 //! \brief    MOS log trace event
 //! \details  log trace event by id and event type, arg1 and arg2 are optional arguments
@@ -2031,9 +1871,9 @@ void MOS_TraceEventClose();
 void MOS_TraceEvent(
     uint16_t         usId,
     uint8_t          ucType,
-    void * const     pArg1,
+    const void       *pArg1,
     uint32_t         dwSize1,
-    void * const     pArg2,
+    const void       *pArg2,
     uint32_t         dwSize2);
 
 //!
@@ -2050,9 +1890,25 @@ void MOS_TraceEvent(
 //! \return   void
 //!
 void MOS_TraceDataDump(
-    char *const pcName,
+    const char *pcName,
     uint32_t    flags,
-    void *const pBuf,
+    const void *pBuf,
+    uint32_t    dwSize);
+
+//!
+//! \brief    MOS log data dictionary item
+//! \details  Dictionary is name:value pair
+//! \param    [in] name
+//!           Indicates item name
+//! \param    [in] pBuf
+//!           Indicates value address
+//! \param    [in] size
+//!           Indicates value size
+//! \return   void
+//!
+void MOS_TraceDataDictionary(
+    const char* pcName,
+    const void* pBuf,
     uint32_t    dwSize);
 
 //!
@@ -2148,6 +2004,33 @@ void MOS_GfxInfo(
     uint8_t         num_of_triples,
     ...);
 
+class MosMutex
+{
+public:
+    MosMutex(void)
+    {
+        m_lock = MOS_CreateMutex();
+    }
+
+    ~MosMutex()
+    {
+        MOS_DestroyMutex(m_lock);
+    }
+
+    void Lock()
+    {
+        MOS_LockMutex(m_lock);
+    }
+
+    void Unlock()
+    {
+        MOS_UnlockMutex(m_lock);
+    }
+
+private:
+    PMOS_MUTEX m_lock = nullptr;
+};
+
 #ifdef __cplusplus
 }
 #endif
