@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2016-2020, Intel Corporation
+* Copyright (c) 2016-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -180,7 +180,6 @@ typedef struct _VPHAL_COMPOSITE_PARAMS
     PVPHAL_ALPHA_PARAMS     pCompAlpha;           //!< Alpha for composited surface
     bool                    bAlphaCalculateEnable;
     bool                    bForceSkipColorFill;  //!< Force skip colorfill even the first layer is translucent
-    bool                    bComputeWlaker;       //!< Compute walker in use
 
     // Resource counters
     int32_t                 nLayers;
@@ -728,6 +727,28 @@ protected:
         return MOS_STATUS_SUCCESS;
     }
 
+    //! \brief    Update Inline Data status
+    //! \param    [in] pSurface
+    //!           point to input Surface
+    //! \param    [in] pStatic
+    //!           Pointer to static data
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise MOS_STATUS_UNKNOWN
+    //!
+    virtual MOS_STATUS UpdateInlineDataStatus(
+        PVPHAL_SURFACE                 pSurface,
+        MEDIA_OBJECT_KA2_STATIC_DATA   *pStatic)
+    {
+        // Just need the sub class to implement if it is needed;
+        return MOS_STATUS_SUCCESS;
+    }
+
+    MOS_STATUS IntermediateAllocation(PVPHAL_SURFACE &pIntermediate,
+        PMOS_INTERFACE                               pOsInterface,
+        uint32_t                                     dwTempWidth,
+        uint32_t                                     dwTempHeight,
+        PVPHAL_SURFACE                               pTarget);
+
     //!
     //! \brief    Prepare phases for composite and allocate intermediate buffer for rendering
     //! \param    [in] pcRenderParams
@@ -892,7 +913,7 @@ private:
     //! \return   bool
     //!           Return true if Bob DI should be enabled, otherwise false
     //!
-    bool IsBobDiEnabled(PVPHAL_SURFACE pSrc);
+    virtual bool IsBobDiEnabled(PVPHAL_SURFACE pSrc);
 
     //!
     //! \brief    Set Composite Layer
@@ -1070,6 +1091,15 @@ private:
     //!
     bool IsSamplerLumakeySupported(PVPHAL_SURFACE pSrc);
 
+    //!
+    //! \brief    Get intermediate surface output
+    //! \param    pOutput
+    //!           [in] Pointer to Intermediate Output Surface
+    //! \return   PVPHAL_SURFACE
+    //!           Return the chose output
+    //!
+    virtual MOS_STATUS GetIntermediateOutput(PVPHAL_SURFACE &output);
+
     // Procamp
     int32_t                         m_iMaxProcampEntries;
     int32_t                         m_iProcampVersion;
@@ -1136,8 +1166,9 @@ protected:
 
     static const int                AVS_CACHE_SIZE = 4;           //!< AVS coefficients cache size
     AvsCoeffsCache<AVS_CACHE_SIZE>  m_AvsCoeffsCache;             //!< AVS coefficients calculation is expensive, add cache to mitigate
-    VPHAL_SURFACE                   m_Intermediate;               //!< Intermediate surface (multiple phase / constriction support)
-    VPHAL_SURFACE                   m_Intermediate2;              //!< Rotation output intermediate surface
+    VPHAL_SURFACE                   m_Intermediate  = {};         //!< Intermediate surface (multiple phase / constriction support)
+    VPHAL_SURFACE                   m_Intermediate1 = {};         //!< Intermediate surface (multiple phase / constriction support)
+    VPHAL_SURFACE                   m_Intermediate2 = {};         //!< Rotation output intermediate surface
 
     Kdll_State                      *m_pKernelDllState = nullptr; //!< Compositing Kernel DLL/Search state
     RENDERHAL_KERNEL_PARAM          m_KernelParams = {0};
