@@ -1,17 +1,23 @@
 /*
-// Copyright (C) 2017-2019, Intel Corporation
-//
-// Licensed under the Apache License,Version 2.0(the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//      http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing,software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
+* Copyright (c) 2017-2020, Intel Corporation
+*
+* Permission is hereby granted, free of charge, to any person obtaining a
+* copy of this software and associated documentation files (the "Software"),
+* to deal in the Software without restriction, including without limitation
+* the rights to use, copy, modify, merge, publish, distribute, sublicense,
+* and/or sell copies of the Software, and to permit persons to whom the
+* Software is furnished to do so, subject to the following conditions:
+*
+* The above copyright notice and this permission notice shall be included
+* in all copies or substantial portions of the Software.
+*
+* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+* OTHER DEALINGS IN THE SOFTWARE.
 */
 //!
 //! \file     codechal_decode_scalability_g12.cpp
@@ -46,10 +52,22 @@ static MOS_STATUS CodecHalDecodeScalability_CalculateScdryCmdBufIndex_G12(
 
     CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase);
     CODECHAL_DECODE_CHK_NULL(pdwBufIdxPlus1);
+    CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL(pScalabilityStateBase->pHwInterface->GetOsInterface());
 
     if (pScalabilityState->HcpDecPhase == CODECHAL_HCP_DECODE_PHASE_REAL_TILE)
     {
         *pdwBufIdxPlus1 = pScalabilityState->u8RtCurPipe + 1;
+        if(pScalabilityStateBase->pHwInterface->GetOsInterface()->phasedSubmission)
+        {
+            /*  3 tiles 2 pipe for example:
+                cur phase               cur pip
+                0                       0, 1                2 cmd buffer needed
+                1                       0                   1 cmd buffer needed
+                all of 3 tiles cmd ready, submit 3 cmd togather
+             */
+            *pdwBufIdxPlus1 += (pScalabilityState->u8RtCurPhase * pScalabilityState->u8RtPhaseNum);
+        }
     }
     else
     {
@@ -609,6 +627,7 @@ MOS_STATUS CodecHalDecodeScalability_DbgDumpCmdBuffer_G12(
     MOS_STATUS                      eStatus = MOS_STATUS_SUCCESS;
     MOS_COMMAND_BUFFER              ScdryCmdBuffer;
     PMOS_COMMAND_BUFFER             pCmdBufferInUse;
+    std::string                     cmdName = "DEC";
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
@@ -630,6 +649,10 @@ MOS_STATUS CodecHalDecodeScalability_DbgDumpCmdBuffer_G12(
     }
     else
     {
+        //calculate bufidx for getting secondary cmd buffer.
+        uint32_t dwBufIdxPlus1 = 0;
+        CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_CalculateScdryCmdBufIndex_G12(pScalabilityState, &dwBufIdxPlus1));
+        cmdName = cmdName + "_secondary_" + std::to_string(dwBufIdxPlus1);
         CODECHAL_DECODE_CHK_STATUS(CodecHalDecodeScalability_GetVESecondaryCmdBuffer_G12(pScalabilityState, &ScdryCmdBuffer));
         pCmdBufferInUse = &ScdryCmdBuffer;
     }
@@ -637,7 +660,7 @@ MOS_STATUS CodecHalDecodeScalability_DbgDumpCmdBuffer_G12(
     CODECHAL_DECODE_CHK_STATUS_RETURN(debugInterface->DumpCmdBuffer(
         pCmdBufferInUse,
         CODECHAL_NUM_MEDIA_STATES,
-        "DEC"));
+        cmdName.c_str()));
 
 finish:
     return eStatus;
@@ -904,10 +927,7 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     vdboxNum = vdboxMfxInterface->GetNumVdbox();
 
     if (vdboxNum < 2
-#if (_DEBUG || _RELEASE_INTERNAL)
-        || !osInterface->bHcpDecScalabilityMode
-#endif
-        )
+        || !osInterface->bHcpDecScalabilityMode)
     {
         eStatus = MOS_STATUS_INVALID_PARAMETER;
         CODECHAL_DECODE_ASSERTMESSAGE("not support scalability on this platform.");
@@ -926,44 +946,50 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_MODE_SWITCH_THRESHOLD1_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dwHcpDecModeSwtichTh1Width = UserFeatureData.u32Data;
 
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_MODE_SWITCH_THRESHOLD2_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dwHcpDecModeSwtichTh2Width = UserFeatureData.u32Data;
 
     // Reg key to control hevc real tile decoding
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
-        __MEDIA_USER_FEATURE_VALUE_DISABLE_HEVC_REALTILE_DECODE_ID_G12,
-        &UserFeatureData);
+        __MEDIA_USER_FEATURE_VALUE_DISABLE_HEVC_REALTILE_DECODE_ID,
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->bDisableRtMode = (UserFeatureData.u32Data != 0);
 
     // Reg key to control hevc real tile multi-phase decoding
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
-        __MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_REALTILE_MULTI_PHASE_DECODE_ID_G12,
-        &UserFeatureData);
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_HEVC_REALTILE_MULTI_PHASE_DECODE_ID,
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->bEnableRtMultiPhase = (UserFeatureData.u32Data != 0);
 
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_SCALABILITY_OVERRIDE_SPLIT_WIDTH_IN_MINCB,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dbgOvrdWidthInMinCb = UserFeatureData.u32Data;
 
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
-        __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_USER_PIPE_NUM_ID_G12,
-        &UserFeatureData);
+        __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_USER_PIPE_NUM_ID,
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->dbgOverUserPipeNum = (uint8_t)UserFeatureData.u32Data;
 #endif
 
@@ -1044,7 +1070,8 @@ MOS_STATUS CodecHalDecodeScalability_InitializeState_G12(
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_HCP_DECODE_ALWAYS_FRAME_SPLIT_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        osInterface->pOsContext);
     pScalabilityState->bAlwaysFrameSplit = UserFeatureData.u32Data ? true : false;
 #endif
 
@@ -1092,6 +1119,7 @@ MOS_STATUS CodecHalDecodeScalability_AdvanceRealTilePass(
 
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalabilityStateBase);
     CODECHAL_DECODE_ASSERT(pScalabilityState->bIsRtMode);
+    CODECHAL_DECODE_ASSERT(pScalabilityState->u8RtCurPhase < pScalabilityState->u8RtPhaseNum);
 
     pScalabilityState->u8RtCurPipe++;
     if (pScalabilityState->u8RtCurPipe >= pScalabilityState->ucScalablePipeNum)
@@ -1100,8 +1128,6 @@ MOS_STATUS CodecHalDecodeScalability_AdvanceRealTilePass(
         pScalabilityState->u8RtCurPhase++;
     }
 
-    CODECHAL_DECODE_ASSERT(pScalabilityState->u8RtCurPhase < pScalabilityState->u8RtPhaseNum);
-
     return eStatus;
 }
 
@@ -1122,8 +1148,8 @@ MOS_STATUS CodecHalDecodeScalability_GetCurrentRealTileColumnId(
 MOS_STATUS CodecHalDecodeScalability_SetSfcState(
     PCODECHAL_DECODE_SCALABILITY_STATE          scalabilityStateBase,
     void                                       *picParams,
-    CODECHAL_RECTANGLE                         *srcRegion,
-    CODECHAL_RECTANGLE                         *dstRegion,
+    CodecRectangle                             *srcRegion,
+    CodecRectangle                             *dstRegion,
     PCODECHAL_DECODE_SFC_SCALABILITY_PARAMS     sfcScalabilityParams)
 {
     MOS_STATUS  eStatus = MOS_STATUS_SUCCESS;
@@ -1212,7 +1238,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
             }
             if (col == hevcPicParams->num_tile_columns_minus1)
             {
-                srcEndX = srcRegion->X + srcRegion->Width - 1;
+                srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
             }
             else
             {
@@ -1245,7 +1271,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
         srcStartX *= maxCbSize;
         if (pipeIndex == scalabilityState->ucScalablePipeNum - 1)
         {
-            srcEndX = srcRegion->X + srcRegion->Width - 1;
+            srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
         }
         else
         {
@@ -1258,7 +1284,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
             if (pipeIndex == 1)
             {
                 srcStartX = scalabilityState->dbgOvrdWidthInMinCb * minCbSize;
-                srcEndX = srcRegion->X + srcRegion->Width - 1;
+                srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
             }
             else
             {
@@ -1277,14 +1303,14 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
         engMode = 0;
         tileType = 0;
         srcStartX = 0;
-        srcEndX = srcRegion->X + srcRegion->Width - 1;
+        srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
     }
 
     // Clamp srcStartX, srcEndX into source region
-    if (srcStartX < srcRegion->X)
-        srcStartX = srcRegion->X;
-    if (srcEndX > srcRegion->X + srcRegion->Width - 1)
-        srcEndX = srcRegion->X + srcRegion->Width - 1;
+    if (srcStartX < srcRegion->m_x)
+        srcStartX = srcRegion->m_x;
+    if (srcEndX > srcRegion->m_x + srcRegion->m_width - 1)
+        srcEndX = srcRegion->m_x + srcRegion->m_width - 1;
 
     if (tileColumnIndex == 0)
     {
@@ -1294,16 +1320,16 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
     }
 
     ildbXOffset = (scalabilityState->Standard == CODECHAL_HEVC) ? 5 : 8;  // 1 : HEVC; 0 : VP9
-    oneBySf = (uint64_t)((double)((uint64_t)(srcRegion->Width) * 524288 / (dstRegion->Width)));
+    oneBySf = (uint64_t)((double)((uint64_t)(srcRegion->m_width) * 524288 / (dstRegion->m_width)));
 
     //------------------ start ildb offset correction -----------------------------//
     srcEndXTemp = srcEndX - ildbXOffset;
 
     //---------------------- destination startX determination logic ---------------//
-    if ((srcRegion->X + srcRegion->Width - 1) <= srcEndXTemp)
+    if ((srcRegion->m_x + srcRegion->m_width - 1) <= srcEndXTemp)
     {
         xOffset = 0;
-        tileEndX = (srcRegion->X + srcRegion->Width);
+        tileEndX = (srcRegion->m_x + srcRegion->m_width);
     }
     else
     {
@@ -1313,7 +1339,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
 
     while (true)
     {
-        if (srcEndXTemp - srcRegion->X < (xOffset + 1))
+        if (srcEndXTemp - srcRegion->m_x < (xOffset + 1))
         {
             dstEndX = 0;
             break;
@@ -1328,14 +1354,14 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
         {
             const uint32_t one_by_sf_fraction_precision = 19;
             const uint32_t beta_precision = 5;
-            uint32_t xPhaseShift = MOS_CLAMP_MIN_MAX(MOS_F_ROUND((((double)srcRegion->Width / dstRegion->Width - 1.0) / 2.0) * 524288.0F), -(1 << (4 + 19)), ((1 << (4 + 19)) - 1));
+            uint32_t xPhaseShift = MOS_CLAMP_MIN_MAX(MOS_F_ROUND((((double)srcRegion->m_width / dstRegion->m_width - 1.0) / 2.0) * 524288.0F), -(1 << (4 + 19)), ((1 << (4 + 19)) - 1));
 
             double tempDestCntx = (((double)scalabilityState->dstXLandingCount * (double)oneBySf) + xPhaseShift);
             if (tempDestCntx < 0)
             {
                 tempDestCntx = 0;
             }
-            xLandingPoint = (double)(((tempDestCntx + ((double)(1 << (one_by_sf_fraction_precision - beta_precision - 1)))) / 524288) + srcRegion->X);
+            xLandingPoint = (double)(((tempDestCntx + ((double)(1 << (one_by_sf_fraction_precision - beta_precision - 1)))) / 524288) + srcRegion->m_x);
         }
 
         if (xLandingPoint >= (double)(tileEndX - xOffset))
@@ -1357,7 +1383,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
     // Last column end at destination region right border.
     if (tileColumnIndex == scalabilityState->lastValidTileIndex)
     {
-        dstEndX = dstRegion->X + dstRegion->Width - 1;
+        dstEndX = dstRegion->m_x + dstRegion->m_width - 1;
     }
 
     if (tileColumnIndex <= scalabilityState->fistValidTileIndex)
@@ -1542,25 +1568,36 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalState);
     CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pVEInterface);
     CODECHAL_DECODE_CHK_NULL_RETURN(pInitParams);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pHwInterface->GetOsInterface());
 
     pVEInterface                                                     = pScalState->pVEInterface;
     pScalState->ucScalablePipeNum                                    = CODECHAL_DECODE_HCP_Legacy_PIPE_NUM_1;
     PCODECHAL_DECODE_SCALABILITY_STATE_G12       pScalStateG12        = static_cast<PCODECHAL_DECODE_SCALABILITY_STATE_G12>(pScalState);
     PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS_G12 pInitParamsG12       = static_cast<PCODECHAL_DECODE_SCALABILITY_INIT_PARAMS_G12>(pInitParams);
-    uint8_t                                     u8MaxTileColumn      = HEVC_NUM_MAX_TILE_COLUMN;
-    bool                                        bCanEnableRealTile   = true;
+    uint8_t                                      u8MaxTileColumn      = HEVC_NUM_MAX_TILE_COLUMN;
+    bool                                         bCanEnableRealTile   = true;
+    bool                                         bCanEnableScalability = !pScalState->pHwInterface->IsDisableScalability();
+    PMOS_INTERFACE pOsInterface                                        = pScalState->pHwInterface->GetOsInterface();
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     bCanEnableRealTile = !(static_cast<PCODECHAL_DECODE_SCALABILITY_STATE_G12>(pScalState))->bDisableRtMode;
     if (!pScalStateG12->bEnableRtMultiPhase)
         u8MaxTileColumn = 2;
 #endif
+    if(!bCanEnableScalability
+        && pOsInterface
+        && (pOsInterface->bHcpDecScalabilityMode == MOS_SCALABILITY_ENABLE_MODE_USER_FORCE))
+    {
+        bCanEnableScalability = true;
+    }
+
     bCanEnableRealTile = bCanEnableRealTile && pInitParamsG12->bIsTileEnabled && (pInitParams->u8NumTileColumns > 1) &&
                          (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW) &&
                          pInitParamsG12->bHasSubsetParams;
 
-    if (pInitParams->usingSFC)
+    if (pInitParams->usingSFC || !bCanEnableScalability)
     {
-        //using SFC can only work in single pipe mode.
         return MOS_STATUS_SUCCESS;
     }
 
@@ -1598,11 +1635,11 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
                         pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_2;
                     }
                 }
-                else if ((!CodechalDecodeNonRextFormat(pInitParams->format)
+                else if ((!pInitParams->usingHistogram) && ((!CodechalDecodeNonRextFormat(pInitParams->format)
                                     && CodechalDecodeResolutionEqualLargerThan4k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
                                 || (CodechalDecodeNonRextFormat(pInitParams->format)
                                     && CodechalDecodeResolutionEqualLargerThan5k(pInitParams->u32PicWidthInPixel, pInitParams->u32PicHeightInPixel))
-                                || (bCanEnableRealTile && !pInitParams->usingSecureDecode))
+                                || (bCanEnableRealTile && (!pOsInterface->osCpInterface->IsCpEnabled() || pOsInterface->bCanEnableSecureRt))))
                 {
                     pScalState->ucScalablePipeNum = CODECHAL_DECODE_HCP_SCALABLE_PIPE_NUM_2;
                 }
@@ -1626,6 +1663,98 @@ MOS_STATUS CodecHalDecodeScalability_DecidePipeNum_G12(
     return eStatus;
 }
 
+
+MOS_STATUS CodechalDecodeScalability_ConstructParmsForGpuCtxCreation_g12(
+    PCODECHAL_DECODE_SCALABILITY_STATE         pScalState,
+    PMOS_GPUCTX_CREATOPTIONS_ENHANCED          gpuCtxCreatOpts,
+    CodechalSetting *                          codecHalSetting)
+{
+    PMOS_INTERFACE                           pOsInterface;
+    CODECHAL_DECODE_SCALABILITY_INIT_PARAMS_G12  initParams;
+    MOS_STATUS                               eStatus = MOS_STATUS_SUCCESS;
+
+    CODECHAL_DECODE_FUNCTION_ENTER;
+
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState);
+    CODECHAL_DECODE_CHK_NULL_RETURN(pScalState->pHwInterface);
+    CODECHAL_DECODE_CHK_NULL_RETURN(gpuCtxCreatOpts);
+    CODECHAL_DECODE_CHK_NULL_RETURN(codecHalSetting);
+    bool sfcInUse = codecHalSetting->sfcInUseHinted && codecHalSetting->downsamplingHinted
+                       && (MEDIA_IS_SKU(pScalState->pHwInterface->GetSkuTable(), FtrSFCPipe)
+                       && !MEDIA_IS_SKU(pScalState->pHwInterface->GetSkuTable(), FtrDisableVDBox2SFC));
+    pOsInterface    = pScalState->pHwInterface->GetOsInterface();
+    MEDIA_FEATURE_TABLE *m_skuTable = pOsInterface->pfnGetSkuTable(pOsInterface);
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (pOsInterface->bEnableDbgOvrdInVE)
+    {
+        PMOS_VIRTUALENGINE_INTERFACE pVEInterface = pScalState->pVEInterface;
+        CODECHAL_DECODE_CHK_NULL_RETURN(pVEInterface);
+        gpuCtxCreatOpts->DebugOverride      = true;
+        if (MEDIA_IS_SKU(m_skuTable, FtrSfcScalability))
+        {
+            gpuCtxCreatOpts->UsingSFC = false;// this param ignored when dbgoverride enabled
+        }
+        else
+        {
+            gpuCtxCreatOpts->UsingSFC = sfcInUse;  // this param ignored when dbgoverride enabled
+        }
+        CODECHAL_DECODE_CHK_STATUS_RETURN(pScalState->pfnDebugOvrdDecidePipeNum(pScalState));
+
+        if (pOsInterface->apoMosEnabled)
+        {
+            CODECHAL_DECODE_CHK_NULL_RETURN(pVEInterface->veInterface);
+            for (uint32_t i = 0; i < pVEInterface->veInterface->GetEngineCount(); i++)
+            {
+                gpuCtxCreatOpts->EngineInstance[i] = pVEInterface->veInterface->GetEngineLogicId(i);
+            }
+        }
+        else
+        {
+            for (uint32_t i = 0; i < pVEInterface->ucEngineCount; i++)
+            {
+                gpuCtxCreatOpts->EngineInstance[i] = pVEInterface->EngineLogicId[i];
+            }
+        }
+    }
+    else
+#endif
+    {
+        if (MEDIA_IS_SKU(m_skuTable, FtrSfcScalability))
+        {
+            gpuCtxCreatOpts->UsingSFC = false;
+        }
+        else
+        {
+            gpuCtxCreatOpts->UsingSFC = sfcInUse;
+        }
+
+        MOS_ZeroMemory(&initParams, sizeof(initParams));
+        initParams.u32PicWidthInPixel   = MOS_ALIGN_CEIL(codecHalSetting->width, 8);
+        initParams.u32PicHeightInPixel  = MOS_ALIGN_CEIL(codecHalSetting->height, 8);
+        if (((codecHalSetting->standard == CODECHAL_VP9) || (codecHalSetting->standard == CODECHAL_HEVC))
+                && (codecHalSetting->chromaFormat == HCP_CHROMA_FORMAT_YUV420))
+        {
+            initParams.format = Format_NV12;
+            if (codecHalSetting->lumaChromaDepth == CODECHAL_LUMA_CHROMA_DEPTH_10_BITS)
+            {
+                initParams.format = Format_P010;
+            }
+        }
+        initParams.usingSFC             = sfcInUse;
+        initParams.usingSecureDecode    = codecHalSetting->secureMode;
+        CODECHAL_DECODE_CHK_STATUS_RETURN(pScalState->pfnDecidePipeNum(
+            pScalState,
+            &initParams));
+    }
+
+    CODECHAL_DECODE_CHK_STATUS_RETURN(pScalState->pfnMapPipeNumToLRCACount(
+        pScalState,
+        &gpuCtxCreatOpts->LRCACount));
+
+    return eStatus;
+}
+
+
 MOS_STATUS CodechalDecodeScalability_MapPipeNumToLRCACount_G12(
     PCODECHAL_DECODE_SCALABILITY_STATE   pScalState,
     uint32_t                             *LRCACount)
