@@ -278,6 +278,10 @@ struct MHW_VDBOX_PIPE_BUF_ADDR_PARAMS_G12 : public MHW_VDBOX_PIPE_BUF_ADDR_PARAM
     PMOS_RESOURCE               presIntraPredLeftReconColStoreBuffer = nullptr;
     PMOS_RESOURCE               presCABACSyntaxStreamOutBuffer = nullptr;
     PMOS_RESOURCE               presCABACSyntaxStreamOutMaxAddr = nullptr;
+
+    //Reference Mmc
+    bool                        bSpecificReferencedMmcRequired = false;
+    MOS_MEMCOMP_STATE           ReferencesMmcState = MOS_MEMCOMP_DISABLED;
 };
 using PMHW_VDBOX_PIPE_BUF_ADDR_PARAMS_G12 = MHW_VDBOX_PIPE_BUF_ADDR_PARAMS_G12 *;
 
@@ -392,7 +396,8 @@ protected:
     };
 
     bool       m_hevcRDOQPerfDisabled = false; //!< Flag to indicate if HEVC RDOQ Perf is disabled
-    uint32_t   m_watchDogTimerThreshold = 0; //!< For Watch Dog Timer threshold on Gen11+
+    uint32_t   m_watchDogTimerThreshold = 0;   //!< For Watch Dog Timer threshold on Gen11+
+    bool       m_disableTlbPrefetch = false;   //!< To disable TLB pre-fetch or not
 
     static const uint32_t   m_HevcSccPaletteSize = 96; //!< For HEVC SCC palette size on Gen12+
     static const uint32_t   m_hcpPakObjSize = MOS_BYTES_TO_DWORDS(sizeof(HcpPakObjectG12));   //!< hcp pak object size
@@ -434,7 +439,8 @@ public:
         MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_RDOQ_PERF_DISABLE_ID,
-            &userFeatureData);
+            &userFeatureData,
+            this->m_osInterface->pOsContext);
 #endif // _DEBUG || _RELEASE_INTERNAL
         m_hevcRDOQPerfDisabled = userFeatureData.i32Data ? true : false;
 
@@ -445,13 +451,25 @@ public:
         MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_WATCHDOG_TIMER_THRESHOLD,
-            &userFeatureData);
+            &userFeatureData,
+            this->m_osInterface->pOsContext);
         if (userFeatureData.u32Data != 0)
         {
             m_watchDogTimerThreshold = userFeatureData.u32Data;
         }
 #endif
 
+        if (MEDIA_IS_WA(m_osInterface->pfnGetWaTable(m_osInterface), Wa_14012254246))
+        {
+            MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
+            MOS_UserFeature_ReadValue_ID(
+                nullptr,
+                __MEDIA_USER_FEATURE_VALUE_DISABLE_TLB_PREFETCH_ID,
+                &userFeatureData,
+                this->m_osInterface->pOsContext);
+            m_disableTlbPrefetch = userFeatureData.u32Data ? true : false;
+        }
+
         m_hevcEncCuRecordSize = sizeof(EncodeHevcCuDataG12);
         m_pakHWTileSizeRecordSize = sizeof(HCPPakHWTileSizeRecord_G12);
 
