@@ -303,6 +303,16 @@ VAStatus DdiEncodeAvc::ParseMiscParamRC(void *data)
     seqParams->FrameSizeTolerance = static_cast<ENCODE_FRAMESIZE_TOLERANCE>(encMiscParamRC->rc_flags.bits.frame_tolerance_mode);
 #endif
 
+#if VA_CHECK_VERSION(1, 10, 0)
+    if (m_encodeCtx->bVdencActive &&
+        (m_encodeCtx->uiRCMethod & (VA_RC_VBR | VA_RC_QVBR | VA_RC_VCM)))
+    {
+        picParams->TargetFrameSize = encMiscParamRC->target_frame_size;
+        // to force VC scenario for TCBRC
+        seqParams->bAutoMaxPBFrameSizeForSceneChange = encMiscParamRC->target_frame_size != 0;
+    }
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -337,6 +347,11 @@ VAStatus DdiEncodeAvc::ParseMiscParamMaxFrameSize(void *data)
     VAEncMiscParameterBufferMaxFrameSize *vaEncMiscParamMaxFrameSize = (VAEncMiscParameterBufferMaxFrameSize *)data;
     DDI_CHK_NULL(seqParams, "nullptr seqParams", VA_STATUS_ERROR_INVALID_PARAMETER);
 
+    if (seqParams->UserMaxFrameSize != vaEncMiscParamMaxFrameSize->max_frame_size >> 3)
+    {
+        seqParams->bResetBRC = 0x1;
+    }
+
     // populate MaxFrameSize from DDI
     seqParams->UserMaxFrameSize = vaEncMiscParamMaxFrameSize->max_frame_size >> 3;  // convert to byte
 
@@ -551,32 +566,19 @@ VAStatus DdiEncodeAvc::ParseMiscParamQualityLevel(void *data)
     VAEncMiscParameterBufferQualityLevel *vaEncMiscParamQualityLevel = (VAEncMiscParameterBufferQualityLevel *)data;
 
     m_encodeCtx->targetUsage = (uint8_t)vaEncMiscParamQualityLevel->quality_level;
-    uint8_t qualityUpperBoundary = TARGETUSAGE_BEST_SPEED;
-#ifdef _FULL_OPEN_SOURCE
-    if (!GFX_IS_PRODUCT(m_encodeCtx->pMediaCtx->platform, IGFX_ICELAKE_LP))
-        qualityUpperBoundary = 5;
-#endif
+
     // check if TU setting is valid, otherwise change to default
-    if ((m_encodeCtx->targetUsage > qualityUpperBoundary) || (0 == m_encodeCtx->targetUsage))
+    if ((m_encodeCtx->targetUsage > TARGETUSAGE_BEST_SPEED) || (0 == m_encodeCtx->targetUsage))
     {
         m_encodeCtx->targetUsage = TARGETUSAGE_RT_SPEED;
-        DDI_ASSERTMESSAGE("Quality Level setting from application is not correct, should be in (0,%d].", qualityUpperBoundary);
-        return VA_STATUS_SUCCESS;
+        DDI_ASSERTMESSAGE("Quality Level setting from application is not correct, should be in (0,%d].", TARGETUSAGE_BEST_SPEED);
     }
 
 #ifdef _FULL_OPEN_SOURCE
-    if (!GFX_IS_PRODUCT(m_encodeCtx->pMediaCtx->platform, IGFX_ICELAKE_LP))
+    if (!GFX_IS_PRODUCT(m_encodeCtx->pMediaCtx->platform, IGFX_ICELAKE_LP) && m_encodeCtx->targetUsage <= 3)
     {
-        if (m_encodeCtx->targetUsage >= 1 && m_encodeCtx->targetUsage <= 2)
-        {
-            m_encodeCtx->targetUsage = 4;
-        }
-        else if (m_encodeCtx->targetUsage >= 3 &&m_encodeCtx->targetUsage <= 5)
-        {
-            m_encodeCtx->targetUsage = 7;
-        }
+        m_encodeCtx->targetUsage = 4;
     }
-
 #endif
 
     return VA_STATUS_SUCCESS;
@@ -2207,6 +2209,7 @@ void DdiEncodeAvc::GetSlcRefIdx(CODEC_PICTURE *picReference, CODEC_PICTURE *slcR
         if (i == CODEC_MAX_NUM_REF_FRAME)
         {
             slcReference->FrameIdx = CODEC_AVC_NUM_UNCOMPRESSED_SURFACE;
+            slcReference->PicFlags = PICTURE_INVALID;
         }
     }
 }
