@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2020, Intel Corporation
+* Copyright (c) 2009-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -207,7 +207,7 @@ VAStatus DdiMediaUtil_AllocateSurface(
         case Media_Format_B10G10R10X2:
         case Media_Format_A16R16G16B16:
         case Media_Format_A16B16G16R16:
-            if (VA_SURFACE_ATTRIB_USAGE_HINT_ENCODER != mediaSurface->surfaceUsageHint   &&
+            if (VA_SURFACE_ATTRIB_USAGE_HINT_ENCODER != mediaSurface->surfaceUsageHint     &&
                 !(mediaSurface->surfaceUsageHint & VA_SURFACE_ATTRIB_USAGE_HINT_VPP_WRITE))
             {
                 tileformat = I915_TILING_NONE;
@@ -224,16 +224,26 @@ VAStatus DdiMediaUtil_AllocateSurface(
                 alignedHeight = MOS_ALIGN_CEIL(height, 2);
                 break;
             }
+
         case Media_Format_RGBP:
         case Media_Format_BGRP:
-        case Media_Format_A8R8G8B8:
-            if (VA_SURFACE_ATTRIB_USAGE_HINT_ENCODER != mediaSurface->surfaceUsageHint &&
+            if (VA_SURFACE_ATTRIB_USAGE_HINT_ENCODER != mediaSurface->surfaceUsageHint   &&
                 !(mediaSurface->surfaceUsageHint & VA_SURFACE_ATTRIB_USAGE_HINT_DECODER) &&
                 !(mediaSurface->surfaceUsageHint & VA_SURFACE_ATTRIB_USAGE_HINT_VPP_WRITE))
             {
                 tileformat = I915_TILING_NONE;
                 break;
             }
+        case Media_Format_A8R8G8B8:
+            if (VA_SURFACE_ATTRIB_USAGE_HINT_ENCODER != mediaSurface->surfaceUsageHint     &&
+                !(mediaSurface->surfaceUsageHint & VA_SURFACE_ATTRIB_USAGE_HINT_DECODER)   &&
+                !(mediaSurface->surfaceUsageHint & VA_SURFACE_ATTRIB_USAGE_HINT_VPP_WRITE) &&
+                !(MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrRenderCompressionOnly)           &&
+                  MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrE2ECompression)))
+            {
+                tileformat = I915_TILING_NONE;
+                break;
+            }
         case Media_Format_NV12:
         case Media_Format_NV21:
         case Media_Format_444P:
@@ -252,6 +262,9 @@ VAStatus DdiMediaUtil_AllocateSurface(
 #endif
         case Media_Format_Y216:
         case Media_Format_AYUV:
+#if VA_CHECK_VERSION(1, 13, 0)
+        case Media_Format_XYUV:
+#endif
         case Media_Format_Y410:
 #if VA_CHECK_VERSION(1, 9, 0)
         case Media_Format_Y412:
@@ -307,6 +320,15 @@ VAStatus DdiMediaUtil_AllocateSurface(
             hRes = VA_STATUS_ERROR_UNSUPPORTED_RT_FORMAT;
             goto finish;
     }
+    //different alignment requirement for different codec and different platform
+    //for MPEG2 and AVC , it should be 16
+    //for HEVC on the platform pre-gen12 (include), it is 64
+    //may need api change for to convey different codec usage.
+    if(VA_SURFACE_ATTRIB_USAGE_HINT_ENCODER & mediaSurface->surfaceUsageHint)
+    {
+        alignedWidth = MOS_ALIGN_CEIL(alignedWidth, 16);
+        alignedHeight = MOS_ALIGN_CEIL(alignedHeight, 16);
+    }
 
     if (DdiMediaUtil_IsExternalSurface(mediaSurface))
     {
@@ -333,6 +355,10 @@ VAStatus DdiMediaUtil_AllocateSurface(
                 uint32_t swizzle_mode;
                 //Overwrite the tile format that matches the exteral buffer
                 mos_bo_get_tiling(bo, &tileformat, &swizzle_mode);
+                if(tileformat == 0)
+                {
+                    tileformat = mediaSurface->pSurfDesc->uiFlags & VA_SURFACE_EXTBUF_DESC_ENABLE_TILING? I915_TILING_Y:I915_TILING_NONE;
+                }
             }
             else
             {
@@ -346,35 +372,12 @@ VAStatus DdiMediaUtil_AllocateSurface(
             if( bo != nullptr )
             {
                 pitch = mediaSurface->pSurfDesc->uiPitches[0];
-                switch (mediaSurface->pSurfDesc->modifier)
-                {
-                    case DRM_FORMAT_MOD_LINEAR:
-                        tileformat = I915_TILING_NONE;
-                        bMemCompEnable = false;
-                        break;
-                    case I915_FORMAT_MOD_X_TILED:
-                        tileformat = I915_TILING_X;
-                        bMemCompEnable = false;
-                        break;
-                    case I915_FORMAT_MOD_Y_TILED:
-                    case I915_FORMAT_MOD_Yf_TILED:
-                        tileformat = I915_TILING_Y;
-                        bMemCompEnable = false;
-                        break;
-                    case I915_FORMAT_MOD_Y_TILED_GEN12_RC_CCS:
-                        tileformat = I915_TILING_Y;
-                        bMemCompEnable = true;
-                        bMemCompRC = true;
-                        break;
-                    case I915_FORMAT_MOD_Y_TILED_GEN12_MC_CCS:
-                        tileformat = I915_TILING_Y;
-                        bMemCompEnable = true;
-                        bMemCompRC = false;
-                        break;
-                    default:
-                        DDI_ASSERTMESSAGE("Unsupported modifier.");
-                        hRes = VA_STATUS_ERROR_INVALID_PARAMETER;
-                        goto finish;
+
+                DDI_CHK_NULL(mediaDrvCtx->m_caps, "nullptr m_caps", VA_STATUS_ERROR_INVALID_CONTEXT);
+                if (VA_STATUS_SUCCESS != mediaDrvCtx->m_caps->SetExternalSurfaceTileFormat(mediaSurface, tileformat, bMemCompEnable, bMemCompRC)) {
+                    DDI_ASSERTMESSAGE("Unsupported modifier.");
+                    hRes = VA_STATUS_ERROR_INVALID_PARAMETER;
+                    goto finish;
                 }
             }
             else
@@ -461,6 +464,21 @@ VAStatus DdiMediaUtil_AllocateSurface(
                             gmmParams.Flags.Info.RenderCompressed = 1;
                         }
 
+                        if(MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrRenderCompressionOnly))
+                        {
+                            gmmParams.Flags.Info.MediaCompressed = 0;
+
+                            if (format == Media_Format_X8R8G8B8 ||
+                                format == Media_Format_X8B8G8R8 ||
+                                format == Media_Format_A8B8G8R8 ||
+                                format == Media_Format_A8R8G8B8 ||
+                                format == Media_Format_R8G8B8A8)
+                            {
+                                gmmParams.Flags.Info.MediaCompressed  = 0;
+                                gmmParams.Flags.Info.RenderCompressed = 1;
+                            }
+                        }
+
                         if(MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrFlatPhysCCS))
                         {
                             gmmParams.Flags.Gpu.UnifiedAuxSurface = 0;
@@ -586,6 +604,8 @@ VAStatus DdiMediaUtil_AllocateSurface(
             mediaSurface->isTiled          = (tileformat != I915_TILING_NONE) ? 1 : 0;
             mediaSurface->pData            = (uint8_t*) bo->virt;
             DDI_VERBOSEMESSAGE("Allocate external surface %7d bytes (%d x %d resource).", mediaSurface->pSurfDesc->uiSize, width, height);
+            uint32_t event[] = {bo->handle, format, width, height, pitch, bo->size, tileformat, cpTag};
+            MOS_TraceEventExt(EVENT_VA_SURFACE, EVENT_TYPE_INFO, event, sizeof(event), &gmmResourceInfo->GetResFlags(), sizeof(GMM_RESOURCE_FLAG));
         }
         else
         {
@@ -644,9 +664,27 @@ VAStatus DdiMediaUtil_AllocateSurface(
                         gmmParams.Flags.Info.RenderCompressed = 1;
                     }
 
-                    if(MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrFlatPhysCCS))
+                    if(MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrRenderCompressionOnly))
                     {
-                        gmmParams.Flags.Gpu.UnifiedAuxSurface = 0;
+                        gmmParams.Flags.Info.MediaCompressed = 0;
+
+                        if (format == Media_Format_X8R8G8B8 ||
+                            format == Media_Format_X8B8G8R8 ||
+                            format == Media_Format_A8B8G8R8 ||
+                            format == Media_Format_A8R8G8B8 ||
+                            format == Media_Format_R8G8B8A8)
+                        {
+                            gmmParams.Flags.Info.MediaCompressed  = 0;
+                            gmmParams.Flags.Info.RenderCompressed = 1;
+                        }
+                        else
+                        {
+                            gmmParams.Flags.Gpu.MMC               = false;
+                            gmmParams.Flags.Info.MediaCompressed  = 0;
+                            gmmParams.Flags.Info.RenderCompressed = 0;
+                            gmmParams.Flags.Gpu.CCS               = 0;
+                            gmmParams.Flags.Gpu.UnifiedAuxSurface = 0;
+                        }
                     }
                 }
                 break;
@@ -1389,26 +1427,18 @@ void DdiMediaUtil_FreeSurface(DDI_MEDIA_SURFACE *surface)
         surface->pMediaCtx->m_auxTableMgr->UnmapResource(surface->pGmmResourceInfo, surface->bo);
     }
 
+    if(surface->bMapped)
+    {
+        DdiMediaUtil_UnlockSurface(surface);
+        DDI_VERBOSEMESSAGE("DDI: try to free a locked surface.");
+    }
+    mos_bo_unreference(surface->bo);
     // For External Buffer, only needs to destory SurfaceDescriptor
-    if ( DdiMediaUtil_IsExternalSurface(surface) )
+    if (surface->pSurfDesc)
     {
-        // In DdiMediaUtil_AllocateSurface call, driver will increase the surface reference count by calling drm_intel_bo_gem_create_from_name
-        // Thus, when freeing the surface, the drm_intel_bo_unreference function should be called to avoid memory leak
-        mos_bo_unreference(surface->bo);
         MOS_FreeMemory(surface->pSurfDesc);
         surface->pSurfDesc = nullptr;
     }
-    else
-    {
-        // calling sequence checking
-        if (surface->bMapped)
-        {
-            DdiMediaUtil_UnlockSurface(surface);
-            DDI_VERBOSEMESSAGE("DDI: try to free a locked surface.");
-        }
-        mos_bo_unreference(surface->bo);
-        surface->bo = nullptr;
-    }
 
     if (nullptr != surface->pGmmResourceInfo)
     {
@@ -1816,3 +1846,40 @@ VAStatus DdiMediaUtil_UnRegisterRTSurfaces(
 
     return VA_STATUS_SUCCESS;
 }
+
+VAStatus DdiMediaUtil_SetMediaResetEnableFlag(PDDI_MEDIA_CONTEXT mediaCtx)
+{
+    mediaCtx->bMediaResetEnable = false;
+    
+    DDI_CHK_NULL(mediaCtx,"nullptr mediaCtx!", VA_STATUS_ERROR_INVALID_CONTEXT);
+    
+    if(!MEDIA_IS_SKU(&mediaCtx->SkuTable, FtrSWMediaReset))
+    {
+        mediaCtx->bMediaResetEnable = false;
+        return VA_STATUS_SUCCESS;
+    }
+
+    mediaCtx->bMediaResetEnable = true;
+
+    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
+    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
+    MOS_USER_FEATURE_INVALID_KEY_ASSERT(
+        MOS_UserFeature_ReadValue_ID(nullptr,
+                                     __MEDIA_USER_FEATURE_VALUE_MEDIA_RESET_ENABLE_ID,
+                                     &userFeatureData,
+                                     nullptr));
+    mediaCtx->bMediaResetEnable = userFeatureData.i32Data ? true : false;
+    if(!mediaCtx->bMediaResetEnable)
+    {
+        return VA_STATUS_SUCCESS;
+    }
+
+    char* mediaResetEnv = getenv("INTEL_MEDIA_RESET_WATCHDOG");
+    if(mediaResetEnv)
+    {
+        mediaCtx->bMediaResetEnable = strcmp(mediaResetEnv, "1") ? false : true;
+        return VA_STATUS_SUCCESS;
+    }
+
+    return VA_STATUS_SUCCESS;
+}
