@@ -46,7 +46,7 @@ public:
         static struct EncodeFormatTable encodeFormatTableTGL[] =
         {
             {AVC, DualPipe, VA_RT_FORMAT_YUV420},
-            {AVC, Vdenc, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV422 | VA_RT_FORMAT_YUV444},
+            {AVC, Vdenc, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV422 | VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_RGB32},
             {HEVC, DualPipe, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP | VA_RT_FORMAT_YUV420_12 |
              VA_RT_FORMAT_YUV422 | VA_RT_FORMAT_YUV422_10 |  VA_RT_FORMAT_YUV422_12},
             {HEVC, Vdenc, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP |
@@ -54,7 +54,7 @@ public:
              VA_RT_FORMAT_RGB32_10BPP | VA_RT_FORMAT_YUV422 | VA_RT_FORMAT_YUV422_10},
             {VP9, Vdenc, VA_RT_FORMAT_YUV420 | VA_RT_FORMAT_YUV420_10BPP |
              VA_RT_FORMAT_YUV444 | VA_RT_FORMAT_YUV444_10 | VA_RT_FORMAT_RGB32 |
-             VA_RT_FORMAT_RGB32_10BPP | VA_RT_FORMAT_YUV422 | VA_RT_FORMAT_YUV422_10},
+             VA_RT_FORMAT_RGB32_10BPP},
         };
         m_encodeFormatTable = (struct EncodeFormatTable*)(&encodeFormatTableTGL[0]);
         m_encodeFormatCount = sizeof(encodeFormatTableTGL)/sizeof(struct EncodeFormatTable);
@@ -128,6 +128,31 @@ public:
 
     virtual CODECHAL_MODE GetDecodeCodecMode(VAProfile profile)                  override;
 
+
+    //!
+    //! \brief    Add surface attributes for Encoding
+    //!
+    //! \param    [in] profile
+    //!           VAProfile of the configuration
+    //!
+    //! \param    [in] entrypoint
+    //!           VAEntrypoint of the configuration
+    //!
+    //! \param    [in,out] attribList
+    //!           Pointer to VASurfaceAttrib array. It returns
+    //!           the supported  surface attributes
+    //!
+    //! \param    [in,out] numAttribs
+    //!           The number of elements allocated on input
+    //!           Return the number of elements actually filled in output
+    //!
+    //! \return   VAStatus
+    //!           VA_STATUS_SUCCESS if success
+    //!
+    virtual VAStatus AddEncSurfaceAttributes(VAProfile profile,
+                                             VAEntrypoint entrypoint,
+                                             VASurfaceAttrib  *attribList,
+                                             uint32_t &numAttribs);
     //!
     //! \brief    Get surface attributes for a given config ID
     //!
@@ -171,6 +196,10 @@ protected:
         CODEC_16K_MAX_PIC_WIDTH; //!< Maximum width for VP9 decode
     static const uint32_t m_decVp9Max16kHeight =
         CODEC_16K_MAX_PIC_HEIGHT; //!< Maximum height for VP9 decode
+    static const uint32_t m_decAv1Max16kWidth =
+        CODEC_16K_MAX_PIC_WIDTH; //!< Maximum width for AV1 decode
+    static const uint32_t m_decAv1Max16kHeight =
+        CODEC_16K_MAX_PIC_HEIGHT; //!< Maximum height for AV1 decode
     static const uint32_t m_maxVp9EncWidth =
         CODEC_8K_MAX_PIC_WIDTH; //!< maximum width for VP9 encode
     static const uint32_t m_maxVp9EncHeight =
@@ -217,7 +246,23 @@ protected:
     //! \return VAStatus
     //!     if call succeeds
     //!
-    VAStatus LoadHevcEncLpProfileEntrypoints();
+    virtual VAStatus LoadHevcEncLpProfileEntrypoints();
+
+    //!
+    //! \brief    Check if the give profile is AV1
+    //!
+    //! \param    [in] profile
+    //!           Specify the VAProfile
+    //!
+    //! \return   True if the profile is a AV1 profile
+    //!           False if the profile isn't a AV1 profile
+    //!
+    static bool IsAV1Profile(VAProfile profile);
+
+    //!
+    //! \brief    Initialize AV1 decode profiles, entrypoints and attributes
+    //!
+    VAStatus LoadAv1DecProfileEntrypoints();
 
     //!
     //! \brief      Query AVC ROI maximum number
@@ -235,5 +280,26 @@ protected:
     //!     if call succeeds
     //!
     VAStatus QueryAVCROIMaxNum(uint32_t rcMode, bool isVdenc, uint32_t *maxNum, bool *isRoiInDeltaQP) override;
+
+    //!
+    //! \brief    Get display attributes
+    //!           returns the current attributes values in "attribList"
+    //!
+    //! \param    [in, out] attribList
+    //!           the attrib type should be filled.
+    //!           returns the supported display attributes
+    //!
+    //! \param    [in] numAttribs
+    //!           the number of supported attributes
+    //!
+    //! \return   VAStatus
+    //!           VA_STATUS_SUCCESS if success
+    //!           VA_STATUS_ERROR_MAX_NUM_EXCEEDED if size of attribList is too small
+    //!
+    virtual VAStatus GetDisplayAttributes(
+            VADisplayAttribute *attribList,
+            int32_t numAttribs) override;
+
+
 };
 #endif
